/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DL3Y.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DL3Y *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DL3Y_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DL3Y();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DL3Y::Heavy_WSTD_DL3Y(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_LIDv6rIS);
  numBytes += sLine_init(&sLine_8c5FyQkv);
  numBytes += sLine_init(&sLine_PbvHOSk1);
  numBytes += sLine_init(&sLine_XCUWjx2u);
  numBytes += sLine_init(&sLine_U56XjQpm);
  numBytes += sBiquad_init(&sBiquad_s_LPklxT2u);
  numBytes += sLine_init(&sLine_wDt7bXSi);
  numBytes += sLine_init(&sLine_0bWLbtcK);
  numBytes += sLine_init(&sLine_XSNUAFuL);
  numBytes += sLine_init(&sLine_8J6NmQYB);
  numBytes += sBiquad_init(&sBiquad_s_UzNXGnQ7);
  numBytes += sLine_init(&sLine_bPYfoZpj);
  numBytes += sLine_init(&sLine_qHd4PwFf);
  numBytes += sLine_init(&sLine_40QdUzT9);
  numBytes += sLine_init(&sLine_GJKuPn86);
  numBytes += sLine_init(&sLine_9O6WBTve);
  numBytes += sBiquad_init(&sBiquad_s_bX69O7g4);
  numBytes += sLine_init(&sLine_UeaU7bYE);
  numBytes += sLine_init(&sLine_xbmhxYlF);
  numBytes += sLine_init(&sLine_JZcuUAUV);
  numBytes += sLine_init(&sLine_7bGU525l);
  numBytes += sLine_init(&sLine_M1L1t4eY);
  numBytes += sBiquad_init(&sBiquad_s_FiCyN7FB);
  numBytes += sLine_init(&sLine_T8plHKWI);
  numBytes += sLine_init(&sLine_qrKWxgpH);
  numBytes += sLine_init(&sLine_Z5wR9mNX);
  numBytes += sLine_init(&sLine_XbTx5iqZ);
  numBytes += sBiquad_init(&sBiquad_s_h3T7jQs6);
  numBytes += sLine_init(&sLine_lZEgVmHV);
  numBytes += sLine_init(&sLine_32Ejqr3u);
  numBytes += sLine_init(&sLine_6RtX3h3U);
  numBytes += sLine_init(&sLine_OxqkCC2F);
  numBytes += sLine_init(&sLine_0Q0OaVzy);
  numBytes += sBiquad_init(&sBiquad_s_7nrJB3Rc);
  numBytes += sLine_init(&sLine_WtpD0Gsk);
  numBytes += sTabread_init(&sTabread_NZ1VWvZz, &hTable_pvg37Ach, true);
  numBytes += sLine_init(&sLine_N65UJtdA);
  numBytes += sLine_init(&sLine_MWz2DHHg);
  numBytes += sTabread_init(&sTabread_YgIkX0EZ, &hTable_ULissyrp, true);
  numBytes += sLine_init(&sLine_Z1TpEUHa);
  numBytes += sRPole_init(&sRPole_t45Kncjf);
  numBytes += sDel1_init(&sDel1_pEozq3vA);
  numBytes += sTabwrite_init(&sTabwrite_9Hqwy0um, &hTable_pvg37Ach);
  numBytes += sRPole_init(&sRPole_PCXo1xpf);
  numBytes += sDel1_init(&sDel1_DO9d1nRT);
  numBytes += sTabwrite_init(&sTabwrite_lCD32ksE, &hTable_ULissyrp);
  numBytes += sLine_init(&sLine_c9Vv0yPN);
  numBytes += sLine_init(&sLine_8CLwTcW5);
  numBytes += sRPole_init(&sRPole_X2zzRKpq);
  numBytes += sEnv_init(&sEnv_hKqfr7RZ, 1024, 512);
  numBytes += sRPole_init(&sRPole_yTHfHdkK);
  numBytes += sLine_init(&sLine_e3LQBVbL);
  numBytes += sLine_init(&sLine_e16Q2KvC);
  numBytes += sRPole_init(&sRPole_eMPW0vRY);
  numBytes += sEnv_init(&sEnv_EYHUWXKn, 1024, 512);
  numBytes += sRPole_init(&sRPole_VrKyfRHX);
  numBytes += sLine_init(&sLine_kbC7tlW3);
  numBytes += sTabread_init(&sTabread_H8j3Mv5R, &hTable_tIkcpiTQ, true);
  numBytes += sLine_init(&sLine_SkqZvgbC);
  numBytes += sLine_init(&sLine_gUYLvKUv);
  numBytes += sTabread_init(&sTabread_1duYvKVV, &hTable_R6QC9LMG, true);
  numBytes += sLine_init(&sLine_mZo6grBN);
  numBytes += sRPole_init(&sRPole_LayV6bLy);
  numBytes += sDel1_init(&sDel1_TjPzs5KD);
  numBytes += sTabwrite_init(&sTabwrite_GVaI3B51, &hTable_tIkcpiTQ);
  numBytes += sRPole_init(&sRPole_6hcL3PV3);
  numBytes += sDel1_init(&sDel1_nq3WJjlb);
  numBytes += sTabwrite_init(&sTabwrite_hxXA0Ub9, &hTable_R6QC9LMG);
  numBytes += sLine_init(&sLine_0vmAP1Gf);
  numBytes += sLine_init(&sLine_ZPnTg4Ib);
  numBytes += sRPole_init(&sRPole_cRQbDWKr);
  numBytes += sEnv_init(&sEnv_krMTioBl, 1024, 512);
  numBytes += sRPole_init(&sRPole_ULT2nLRf);
  numBytes += sLine_init(&sLine_uPiQ8yFp);
  numBytes += sLine_init(&sLine_XBVr5HVD);
  numBytes += sRPole_init(&sRPole_nWoAChs7);
  numBytes += sEnv_init(&sEnv_XeyV0Ym3, 1024, 512);
  numBytes += sRPole_init(&sRPole_ENaMTTPu);
  numBytes += sLine_init(&sLine_oJApnkjr);
  numBytes += sTabread_init(&sTabread_TNHnOogk, &hTable_zQosuoI8, true);
  numBytes += sLine_init(&sLine_qieurbsu);
  numBytes += sLine_init(&sLine_Sf2HLxBC);
  numBytes += sTabread_init(&sTabread_lvKnOXvR, &hTable_WdxksEEm, true);
  numBytes += sLine_init(&sLine_OZGoxHJP);
  numBytes += sRPole_init(&sRPole_nnAHvv3j);
  numBytes += sDel1_init(&sDel1_EOMF4avP);
  numBytes += sTabwrite_init(&sTabwrite_9moBFLi6, &hTable_zQosuoI8);
  numBytes += sRPole_init(&sRPole_6xEzI162);
  numBytes += sDel1_init(&sDel1_ZYovEKlW);
  numBytes += sTabwrite_init(&sTabwrite_qVjxfyn4, &hTable_WdxksEEm);
  numBytes += sLine_init(&sLine_qhEKHd4g);
  numBytes += sLine_init(&sLine_kf650xJu);
  numBytes += sRPole_init(&sRPole_c7mmTfDt);
  numBytes += sEnv_init(&sEnv_Clk8TEtC, 1024, 512);
  numBytes += sRPole_init(&sRPole_ZoL54tmP);
  numBytes += sLine_init(&sLine_NA0Ve62B);
  numBytes += sLine_init(&sLine_rnnAS4eN);
  numBytes += sRPole_init(&sRPole_3wDQZBaT);
  numBytes += sEnv_init(&sEnv_xr4LKy92, 1024, 512);
  numBytes += sRPole_init(&sRPole_upKmZYYz);
  numBytes += cVar_init_f(&cVar_iEYmPGIU, 0.0f);
  numBytes += cVar_init_f(&cVar_OPhG1dr6, 0.0f);
  numBytes += cVar_init_f(&cVar_yDyiZKqd, 0.0f);
  numBytes += cVar_init_f(&cVar_cArpoG2G, 0.0f);
  numBytes += cSlice_init(&cSlice_FWJmyOjh, 1, -1);
  numBytes += cVar_init_f(&cVar_5m6Gdztd, 1337.0f);
  numBytes += cVar_init_f(&cVar_yDFg27R4, 0.0f);
  numBytes += cIf_init(&cIf_8TApKNMQ, false);
  numBytes += cIf_init(&cIf_8rk3tDV6, false);
  numBytes += cBinop_init(&cBinop_T1fwXGj5, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Sc3EkTo3, false);
  numBytes += cBinop_init(&cBinop_NjUscC5e, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_9FL4FEFY, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_gLyk1x7Y, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_auww2T16, 0.0f);
  numBytes += cIf_init(&cIf_Owu6Dx3s, false);
  numBytes += cIf_init(&cIf_nTeD2w7d, false);
  numBytes += cBinop_init(&cBinop_BmtVcjmq, 0.0f); // __pow
  numBytes += cIf_init(&cIf_PEGGxd6B, false);
  numBytes += cBinop_init(&cBinop_dOGUpozm, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_8UWR4egV, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_SlH4dacf, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_jirMLA57, 0.0f);
  numBytes += cIf_init(&cIf_2nvzcbCy, false);
  numBytes += cIf_init(&cIf_8cVJOhun, false);
  numBytes += cBinop_init(&cBinop_Zo9z1Y44, 0.0f); // __pow
  numBytes += cIf_init(&cIf_yf8cLiYb, false);
  numBytes += cBinop_init(&cBinop_o84l534R, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_DJfV948L, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_6U9ncUyT, -15.0f); // __eq
  numBytes += cIf_init(&cIf_MXT6gXfG, false);
  numBytes += cSlice_init(&cSlice_RFHL6C1R, 1, -1);
  numBytes += cVar_init_f(&cVar_pkEFZkkX, 0.0f);
  numBytes += cSlice_init(&cSlice_0lSMf5i1, 1, -1);
  numBytes += cVar_init_f(&cVar_BizChS8l, 0.0f);
  numBytes += cSlice_init(&cSlice_AxWOa4E1, 1, -1);
  numBytes += cVar_init_f(&cVar_6QGPj3hb, 0.0f);
  numBytes += cSlice_init(&cSlice_HpYfzDja, 1, -1);
  numBytes += cVar_init_f(&cVar_jQHhTPcE, 0.313f);
  numBytes += cBinop_init(&cBinop_UEKzBeOU, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_JjrknCMR, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_V5js6U9P, 0.0f);
  numBytes += cVar_init_f(&cVar_fEiru1KC, 1337.0f);
  numBytes += cVar_init_f(&cVar_Rtm0UQLR, 0.3f);
  numBytes += cBinop_init(&cBinop_5HAg9387, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_On9ylkws, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CzIsdB9w, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qcxSvOR8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6wT5HNEk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_D8Mm8zkV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DXuoYWi4, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_digXPp0A, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_5XEOEXpX, 0.0f);
  numBytes += cVar_init_f(&cVar_JyomrtGA, 1337.0f);
  numBytes += cVar_init_f(&cVar_UEhGpAyP, 0.313f);
  numBytes += cBinop_init(&cBinop_2VqbExI0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_pgFDMQfY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4HdN6Ywy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XX4YmjCL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LukmkSMF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DcoR3avz, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_UneegEgm, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_2WHNfc2J, 0.0f);
  numBytes += cVar_init_f(&cVar_g3Z234Yo, 1037.0f);
  numBytes += cVar_init_f(&cVar_bJNgaoqZ, 0.4f);
  numBytes += cBinop_init(&cBinop_gZset3dE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4ZZnkq5i, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PqFN7w4S, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rXfvAINm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Tb8HFi3b, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9qlDJ67J, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_S0eUwEr0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uYRUIAgJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VmCXx4sK, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_LiQn4QYc, 1, -1);
  numBytes += cVar_init_f(&cVar_PIw5c6QT, 1337.0f);
  numBytes += cVar_init_f(&cVar_jTYRqwER, 0.0f);
  numBytes += cIf_init(&cIf_tmRn2FdH, false);
  numBytes += cIf_init(&cIf_CZIcHgqa, false);
  numBytes += cBinop_init(&cBinop_qSyYKezB, 0.0f); // __pow
  numBytes += cIf_init(&cIf_6kkpEglA, false);
  numBytes += cBinop_init(&cBinop_oXiZdQSz, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_onebWDZj, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_pqEizlIo, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_5b0RviJn, 0.0f);
  numBytes += cIf_init(&cIf_ml2IWbQI, false);
  numBytes += cIf_init(&cIf_HFQI8wiG, false);
  numBytes += cBinop_init(&cBinop_7QE5iK4T, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Bj3PARrF, false);
  numBytes += cBinop_init(&cBinop_OABMlurd, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_EkYhEv2U, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_J3dyNbNP, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_v9DOjPkW, 0.0f);
  numBytes += cIf_init(&cIf_sfKbcfzg, false);
  numBytes += cIf_init(&cIf_mlb1ktYC, false);
  numBytes += cBinop_init(&cBinop_8GddyK3u, 0.0f); // __pow
  numBytes += cIf_init(&cIf_eAWdD2YT, false);
  numBytes += cBinop_init(&cBinop_B34wWSAd, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_uAmgZGXg, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_9ddss8aB, -15.0f); // __eq
  numBytes += cIf_init(&cIf_G5BuEctb, false);
  numBytes += cSlice_init(&cSlice_stLoRWaF, 1, -1);
  numBytes += cVar_init_f(&cVar_f3nIbJFF, 0.0f);
  numBytes += cSlice_init(&cSlice_rKY19Nsv, 1, -1);
  numBytes += cVar_init_f(&cVar_qWRbiOJY, 0.0f);
  numBytes += cSlice_init(&cSlice_1WDwr2P9, 1, -1);
  numBytes += cVar_init_f(&cVar_PxlzcX9q, 0.0f);
  numBytes += cSlice_init(&cSlice_tiMvmVg7, 1, -1);
  numBytes += cVar_init_f(&cVar_H0CEWVNK, 0.313f);
  numBytes += cBinop_init(&cBinop_2pDn2mMA, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_QBXaos29, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_uEFMghIh, 0.0f);
  numBytes += cVar_init_f(&cVar_7zyL7ajd, 1337.0f);
  numBytes += cVar_init_f(&cVar_e3GOrZS4, 0.3f);
  numBytes += cBinop_init(&cBinop_MEP31SrZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MjFtpEVO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cUlZ10Tb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7TYIvE8A, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_c9cLPSbT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_82NdA0G9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NaikdOpl, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_31cXL69M, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_gUO2UQel, 0.0f);
  numBytes += cVar_init_f(&cVar_eyQEDmhc, 1337.0f);
  numBytes += cVar_init_f(&cVar_mQz0k6M2, 0.313f);
  numBytes += cBinop_init(&cBinop_Z95C3egD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FiPlHaay, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_d7Oa4JFv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DWXHqoqu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HbwDUTE2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OfwAxfuc, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_WfI2ozje, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_wG8igew4, 0.0f);
  numBytes += cVar_init_f(&cVar_cpJ0nrvG, 1037.0f);
  numBytes += cVar_init_f(&cVar_BAYMWNS8, 0.4f);
  numBytes += cBinop_init(&cBinop_KPJeRpuF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lRUgFuSM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_X6VkIiE5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_H8T5j3p5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Qh3dNMmm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yn6BJ4YV, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_PJYDr6jw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_l0HWETlD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Dr4Eayap, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_7WcuRte4, 5705.6f);
  numBytes += cVar_init_f(&cVar_Kk1rc6QO, 313.3f);
  numBytes += cBinop_init(&cBinop_U97EiOEm, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_Twve1onL, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_O5u3MaAe, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_FXSOmsEf, 0.0f);
  numBytes += cVar_init_f(&cVar_LVL2uYbg, 0.0f);
  numBytes += cVar_init_f(&cVar_EUnyKhAx, 0.0f);
  numBytes += cVar_init_f(&cVar_Q0SxFpBF, 0.0f);
  numBytes += cVar_init_f(&cVar_jECbaHV1, 0.0f);
  numBytes += cVar_init_f(&cVar_okbRqMm6, 0.0f);
  numBytes += cVar_init_f(&cVar_nNNVrZty, 0.0f);
  numBytes += cVar_init_f(&cVar_VndE8skE, 0.0f);
  numBytes += cVar_init_f(&cVar_oVEoaXRF, 0.0f);
  numBytes += cVar_init_f(&cVar_C8V0v6Pm, 0.0f);
  numBytes += cVar_init_f(&cVar_DDpKa7gs, 0.0f);
  numBytes += cVar_init_f(&cVar_eCZxXDJF, 0.0f);
  numBytes += cSlice_init(&cSlice_kRnJ4Lz3, 1, -1);
  numBytes += cVar_init_f(&cVar_QL8s1aHe, 0.5f);
  numBytes += cSlice_init(&cSlice_AbElgA2m, 1, -1);
  numBytes += cVar_init_f(&cVar_uJ9naidV, 0.2f);
  numBytes += cSlice_init(&cSlice_agz80tcb, 1, -1);
  numBytes += cVar_init_f(&cVar_9AsgeOTx, 500.0f);
  numBytes += sVarf_init(&sVarf_s1XQ22LP, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_BSUpe4iS, 600.0f);
  numBytes += cBinop_init(&cBinop_7Zz9xx5I, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_V0rpZrcw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AtEVUevM, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_frTSLTPQ, 600.0f);
  numBytes += cBinop_init(&cBinop_SdZLZdcM, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_GC7HnffY, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_BwfW4ZsZ, 4000.0f);
  numBytes += cBinop_init(&cBinop_6IFRQgtm, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_hy0hoSSq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EocdERQG, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_NCEeNUML, 4000.0f);
  numBytes += cBinop_init(&cBinop_iyeMHhmL, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_b4hL9Yaq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_h4MYRIoY, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_ticmwFmx, false);
  numBytes += cBinop_init(&cBinop_YV1Jl7wa, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_TuGilJ0a, 20.0f);
  numBytes += cBinop_init(&cBinop_qxWc7yR9, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_GFrx5vap, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_opEgIqvz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AvuWGbS4, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_bMzd1Jqg, false);
  numBytes += cBinop_init(&cBinop_Rj6A0UmP, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_CpRBNaTb, 20.0f);
  numBytes += cBinop_init(&cBinop_2i9b2eB4, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ssK9RI9d, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rQ3v3kcI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lKvCRRI2, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_qk68sJ50, 1, -1);
  numBytes += cVar_init_f(&cVar_l9w4TKoq, 0.25f);
  numBytes += cDelay_init(this, &cDelay_p16THOOl, 0.0f);
  numBytes += cDelay_init(this, &cDelay_2u0eElsG, 0.0f);
  numBytes += hTable_init(&hTable_pvg37Ach, 256);
  numBytes += cTabhead_init(&cTabhead_rf4irwnQ, &hTable_pvg37Ach);
  numBytes += cVar_init_s(&cVar_yrTI7bzk, "del-1349-delayL");
  numBytes += cDelay_init(this, &cDelay_kqpoCzMa, 0.0f);
  numBytes += cDelay_init(this, &cDelay_q755FTMM, 0.0f);
  numBytes += cBinop_init(&cBinop_sIjZ187J, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_y8qnviG0, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_ckL2brDp, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_Ls58UR87, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_vDX1Sk5L, 0.0f);
  numBytes += cDelay_init(this, &cDelay_uYY5fZAu, 0.0f);
  numBytes += hTable_init(&hTable_ULissyrp, 256);
  numBytes += cTabhead_init(&cTabhead_lqA7i9xe, &hTable_ULissyrp);
  numBytes += cVar_init_s(&cVar_NgDPgs0Q, "del-1349-delayR");
  numBytes += cDelay_init(this, &cDelay_7Vaq8Sgh, 0.0f);
  numBytes += cDelay_init(this, &cDelay_rTghhiZu, 0.0f);
  numBytes += cBinop_init(&cBinop_qS8cnV3X, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_C8cbEhKJ, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_68XSSo9U, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_mNGEltvB, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_BJ7GM4pv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NDlKgxQs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Gv8w1eOI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ryTsxw1M, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_xvF6Cnou, 1, -1);
  numBytes += cVar_init_f(&cVar_lJuSV4wK, 0.5f);
  numBytes += cSlice_init(&cSlice_7EljwBeR, 1, -1);
  numBytes += cVar_init_f(&cVar_JeyQPUGb, 0.2f);
  numBytes += cSlice_init(&cSlice_xvQ3vigJ, 1, -1);
  numBytes += cVar_init_f(&cVar_JfOQgcq4, 500.0f);
  numBytes += sVarf_init(&sVarf_3wErOXN5, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ED8TD539, 600.0f);
  numBytes += cBinop_init(&cBinop_ERjjfsCE, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_uK6fvLe4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_76KePY8D, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_eP31zxli, 600.0f);
  numBytes += cBinop_init(&cBinop_gRffBZ3n, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_j6G5hSeR, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_BLdF1htW, 4000.0f);
  numBytes += cBinop_init(&cBinop_GXv8UDmv, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_3Ek4F72y, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XhCODwB3, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_OseGkUYq, 4000.0f);
  numBytes += cBinop_init(&cBinop_DfiD2fip, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_6ckZ2wdP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8ORepZw7, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_LeB4ZprE, false);
  numBytes += cBinop_init(&cBinop_3pUkrpk5, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_vTuS20a3, 20.0f);
  numBytes += cBinop_init(&cBinop_XiwaYKgw, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_IPdAf4ij, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xokkUKU2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7VYzuSOu, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_qvv44Wan, false);
  numBytes += cBinop_init(&cBinop_OUkzYUSa, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_QGqNZlnT, 20.0f);
  numBytes += cBinop_init(&cBinop_XEvRRxEj, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_KMtsKznu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ILTDV76F, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mUPS5F7G, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_Eh3e7R1P, 1, -1);
  numBytes += cVar_init_f(&cVar_DTFHTi7r, 0.25f);
  numBytes += cDelay_init(this, &cDelay_TkijY6Ef, 0.0f);
  numBytes += cDelay_init(this, &cDelay_h5PDnZvd, 0.0f);
  numBytes += hTable_init(&hTable_tIkcpiTQ, 256);
  numBytes += cTabhead_init(&cTabhead_yjxowaRp, &hTable_tIkcpiTQ);
  numBytes += cVar_init_s(&cVar_WN3NeLVc, "del-1428-delayL");
  numBytes += cDelay_init(this, &cDelay_ixrkTwNC, 0.0f);
  numBytes += cDelay_init(this, &cDelay_ywZrNkZO, 0.0f);
  numBytes += cBinop_init(&cBinop_kS6OsUbT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NtlLjZFm, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_9HxIYjlG, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_2OIpGRX5, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_1l6rhR8U, 0.0f);
  numBytes += cDelay_init(this, &cDelay_kl4xJxie, 0.0f);
  numBytes += hTable_init(&hTable_R6QC9LMG, 256);
  numBytes += cTabhead_init(&cTabhead_dp7MHElX, &hTable_R6QC9LMG);
  numBytes += cVar_init_s(&cVar_RGRsFYTT, "del-1428-delayR");
  numBytes += cDelay_init(this, &cDelay_tT8vQaUI, 0.0f);
  numBytes += cDelay_init(this, &cDelay_tpY7ePd8, 0.0f);
  numBytes += cBinop_init(&cBinop_YzK6Zf00, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xlgd6JhG, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_fq3TwX0l, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_lUkTV9kf, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_kFy3pBdp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_h15eznd7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3jGu32vx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_a0kNWccw, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_dJ52ODpa, 1, -1);
  numBytes += cVar_init_f(&cVar_0cZ72tdI, 0.5f);
  numBytes += cSlice_init(&cSlice_KT7b0ZO7, 1, -1);
  numBytes += cVar_init_f(&cVar_LsHytMnZ, 0.2f);
  numBytes += cSlice_init(&cSlice_Afd38MNH, 1, -1);
  numBytes += cVar_init_f(&cVar_1FdGZiUq, 500.0f);
  numBytes += sVarf_init(&sVarf_mYQGE8nj, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_4fWp4xFj, 600.0f);
  numBytes += cBinop_init(&cBinop_ZIWVcgm2, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_uOeFCiAM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_v3qS2Prz, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_AnYAvHjT, 600.0f);
  numBytes += cBinop_init(&cBinop_piJOCK87, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_n65hW3z8, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_3NGJbWen, 4000.0f);
  numBytes += cBinop_init(&cBinop_PHyWgwUu, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_dFf4AG4d, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KoTCHrby, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_epOBZTyg, 4000.0f);
  numBytes += cBinop_init(&cBinop_YodZxj7I, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_LBtFoJGf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GoroJi3d, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_JKv2xJlP, false);
  numBytes += cBinop_init(&cBinop_jLCFLvbu, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_lkntZ5tU, 20.0f);
  numBytes += cBinop_init(&cBinop_OZ4rJAga, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_XVOT2BKK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1gj8Tchl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yDMd3E35, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_IY0XCzTL, false);
  numBytes += cBinop_init(&cBinop_R9Mv2V0c, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_gA8ynNvu, 20.0f);
  numBytes += cBinop_init(&cBinop_j0kOdvM1, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_IeU07rch, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4pG47vTr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_miZDJRwS, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_FyTUX6HZ, 1, -1);
  numBytes += cVar_init_f(&cVar_1Zgo1DLf, 0.25f);
  numBytes += cDelay_init(this, &cDelay_465dz1pZ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_TbByjULY, 0.0f);
  numBytes += hTable_init(&hTable_zQosuoI8, 256);
  numBytes += cTabhead_init(&cTabhead_XGgUtqGl, &hTable_zQosuoI8);
  numBytes += cVar_init_s(&cVar_D4Li5Iy1, "del-1507-delayL");
  numBytes += cDelay_init(this, &cDelay_dK81C5DS, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Qwc0Ko76, 0.0f);
  numBytes += cBinop_init(&cBinop_FF1KCjVU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NiRgAZ7J, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_428F5rDC, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_6JHEOy4V, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_YYzsFzKv, 0.0f);
  numBytes += cDelay_init(this, &cDelay_aSJa9FPk, 0.0f);
  numBytes += hTable_init(&hTable_WdxksEEm, 256);
  numBytes += cTabhead_init(&cTabhead_KaSI3bRJ, &hTable_WdxksEEm);
  numBytes += cVar_init_s(&cVar_xSUIXNAt, "del-1507-delayR");
  numBytes += cDelay_init(this, &cDelay_P30o4txL, 0.0f);
  numBytes += cDelay_init(this, &cDelay_e5F5PvIP, 0.0f);
  numBytes += cBinop_init(&cBinop_613FymEU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SLGTMlgE, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_JAVzRyxf, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_Rna3OhDD, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_de67Gy0Q, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_d37GXx8y, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_af3JUSCP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8Ae3Tq4R, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_i2BdllbW, 1.0f);
  numBytes += cIf_init(&cIf_NS4oJ32f, false);
  numBytes += cIf_init(&cIf_HxlCLJr8, false);
  numBytes += cVar_init_f(&cVar_1NBNOIEN, 0.0f);
  numBytes += cVar_init_f(&cVar_fcrcgDG3, 0.0f);
  numBytes += cVar_init_f(&cVar_xEH12WGU, 1.0f);
  numBytes += cIf_init(&cIf_JUbX7TjI, false);
  numBytes += cIf_init(&cIf_kzFBLqP3, false);
  numBytes += cVar_init_f(&cVar_IFOeUItP, 0.0f);
  numBytes += cVar_init_f(&cVar_FRkQu1KY, 0.0f);
  numBytes += cVar_init_f(&cVar_e7pywYmq, 1.0f);
  numBytes += cIf_init(&cIf_EPwqyfxX, false);
  numBytes += cIf_init(&cIf_3hOKLDLe, false);
  numBytes += cVar_init_f(&cVar_pGE0PJpt, 0.0f);
  numBytes += cVar_init_f(&cVar_rJvoVElD, 0.0f);
  numBytes += cVar_init_f(&cVar_XyJRdx9u, 60000.0f);
  numBytes += cVar_init_f(&cVar_axyATaX2, 500.0f);
  numBytes += cSlice_init(&cSlice_GWbLPdgH, 1, -1);
  numBytes += cSlice_init(&cSlice_q4JEU4EC, 1, -1);
  numBytes += cVar_init_f(&cVar_BC7fr6ky, 0.0f);
  numBytes += cIf_init(&cIf_88t8JoBS, false);
  numBytes += cBinop_init(&cBinop_jrdtoZZb, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_pbTAsBcY, 120.0f);
  numBytes += cBinop_init(&cBinop_KQtRPJbr, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_q1tvgkab, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_7Xk1PU3l, 60000.0f);
  numBytes += cVar_init_f(&cVar_JVmJ2scr, 500.0f);
  numBytes += cSlice_init(&cSlice_ujuuKL39, 1, -1);
  numBytes += cSlice_init(&cSlice_K1OCLzEO, 1, -1);
  numBytes += cVar_init_f(&cVar_pUZcH9r1, 0.0f);
  numBytes += cIf_init(&cIf_6QO4NtSj, false);
  numBytes += cBinop_init(&cBinop_dQOPGNKT, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_TBWcGfxn, 120.0f);
  numBytes += cBinop_init(&cBinop_IUPUS0EF, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_120uPKTm, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_lUkzLh7N, 60000.0f);
  numBytes += cVar_init_f(&cVar_15PEC01x, 500.0f);
  numBytes += cSlice_init(&cSlice_lCwm74h2, 1, -1);
  numBytes += cSlice_init(&cSlice_YZi7tRjV, 1, -1);
  numBytes += cVar_init_f(&cVar_pLOUl3zX, 0.0f);
  numBytes += cIf_init(&cIf_ah454S6O, false);
  numBytes += cBinop_init(&cBinop_VlxQVwdw, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_9pjitEH2, 120.0f);
  numBytes += cBinop_init(&cBinop_ReL3izOe, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_rE2NFiA0, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_QAAKarGp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PtH0yAe8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5WBtEl04, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XQHAdqGa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZwjB9Smw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ELbtfhiu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_t1vGq2GG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_93pwV1JT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_m46LfR0g, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HH7Fi7Ds, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DL3Y::~Heavy_WSTD_DL3Y() {
  sEnv_free(&sEnv_hKqfr7RZ);
  sEnv_free(&sEnv_EYHUWXKn);
  sEnv_free(&sEnv_krMTioBl);
  sEnv_free(&sEnv_XeyV0Ym3);
  sEnv_free(&sEnv_Clk8TEtC);
  sEnv_free(&sEnv_xr4LKy92);
  hTable_free(&hTable_pvg37Ach);
  hTable_free(&hTable_ULissyrp);
  hTable_free(&hTable_tIkcpiTQ);
  hTable_free(&hTable_R6QC9LMG);
  hTable_free(&hTable_zQosuoI8);
  hTable_free(&hTable_WdxksEEm);
}

HvTable *Heavy_WSTD_DL3Y::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x29B74AF: return &hTable_pvg37Ach; // del-1349-delayL
    case 0x19A00729: return &hTable_ULissyrp; // del-1349-delayR
    case 0x584C8281: return &hTable_tIkcpiTQ; // del-1428-delayL
    case 0x54BF59F6: return &hTable_R6QC9LMG; // del-1428-delayR
    case 0xBCE693A: return &hTable_zQosuoI8; // del-1507-delayL
    case 0x95A380B3: return &hTable_WdxksEEm; // del-1507-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DL3Y::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8XnY2iXw_sendMessage);
      break;
    }
    case 0xBB584857: { // High_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZOVfcOdR_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FEQ3rbAd_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xZdyiYPK_sendMessage);
      break;
    }
    case 0xDD62B09F: { // High_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WuHwjp2A_sendMessage);
      break;
    }
    case 0xABB0CBCF: { // High_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BMGJpY6E_sendMessage);
      break;
    }
    case 0xAE942A2: { // High_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hFwbynG1_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aR9ZJvnA_sendMessage);
      break;
    }
    case 0xA2D68920: { // Low_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hdg7Yvca_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TR8B1dqv_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fowVqtZv_sendMessage);
      break;
    }
    case 0xFFFEE96: { // Low_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jDzF8Uhp_sendMessage);
      break;
    }
    case 0xA3BD8A20: { // Low_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VAXTZuzA_sendMessage);
      break;
    }
    case 0x67F58CFB: { // Low_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qZ0zlwId_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_e1qvkXlW_sendMessage);
      break;
    }
    case 0x59607D3: { // Mid_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EOu1cagy_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HhlVaHJ6_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_w8hGfB25_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_C7PU5adQ_sendMessage);
      break;
    }
    case 0x96E19510: { // Mid_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Jlyrsq9A_sendMessage);
      break;
    }
    case 0xE1DB1774: { // Mid_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vVkarKl2_sendMessage);
      break;
    }
    case 0xDB67B94E: { // Mid_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BWzKE6qK_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_h2Em4w1r_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kzo7MmnU_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nZGIJqNM_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Af8HtmiZ_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ktWlRPnp_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZYEkmImP_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3F9ooVLF_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eVVFJLDm_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cW44edgK_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qwrRXovp_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QJvfupdR_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KIjt0MyX_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oiH93lti_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_quAKfBBL_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_q8p8jqyl_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pPiQGzox_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3qn6oHRv_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4yZXA2n7_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hexPoHfL_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jZRZbRDn_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BotDdeNS_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VbMm6jGb_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ewyCV9dM_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8XKCNsZT_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AdP0OpFx_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R4SFKb0S_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IMKkYORq_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FOxKVdgZ_sendMessage);
      break;
    }
    case 0x9FC1C9E5: { // 1349-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_G0df0oxm_sendMessage);
      break;
    }
    case 0x5D7BD4E9: { // 1349-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ICcnLC2m_sendMessage);
      break;
    }
    case 0x371A347A: { // 1349-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_49jy3Vkg_sendMessage);
      break;
    }
    case 0x810E74BC: { // 1349-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2ss8ImUC_sendMessage);
      break;
    }
    case 0xCC56B3CF: { // 1428-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xSLalnLB_sendMessage);
      break;
    }
    case 0x499A953B: { // 1428-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_swMhpeo3_sendMessage);
      break;
    }
    case 0xE0E7225B: { // 1428-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2tVSyGDU_sendMessage);
      break;
    }
    case 0xE6486F5F: { // 1428-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5oB3GbW0_sendMessage);
      break;
    }
    case 0xF65E8330: { // 1507-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bVB9sUC1_sendMessage);
      break;
    }
    case 0x3B8B5FB8: { // 1507-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ggeTR9Zt_sendMessage);
      break;
    }
    case 0xE5F26E0D: { // 1507-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_y0Xt0krk_sendMessage);
      break;
    }
    case 0xFDAB8735: { // 1507-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GIfFJYiA_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4KHviVyQ_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_d9VLBbaA_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DL3Y::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Cross";
        info->hash = 0xBB584857;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Sync";
        info->hash = 0xDD62B09F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "High_Time";
        info->hash = 0xABB0CBCF;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 6: {
        info->name = "High_TimeSync";
        info->hash = 0xAE942A2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 7: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low_Cross";
        info->hash = 0xA2D68920;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 9: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 10: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 11: {
        info->name = "Low_Sync";
        info->hash = 0xFFFEE96;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Time";
        info->hash = 0xA3BD8A20;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 13: {
        info->name = "Low_TimeSync";
        info->hash = 0x67F58CFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 14: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Cross";
        info->hash = 0x59607D3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 16: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Sync";
        info->hash = 0x96E19510;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Time";
        info->hash = 0xE1DB1774;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 21: {
        info->name = "Mid_TimeSync";
        info->hash = 0xDB67B94E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 22;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DL3Y::cVar_iEYmPGIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I7sqdTHN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_OPhG1dr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NuBGf5IU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_yDyiZKqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ENxpPN1Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_cArpoG2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EM2Sc9DW_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5xrx0dqF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OIA2ZmPX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TtpPTW1R_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_gQGNZMVS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FWJmyOjh, 0, m, &cSlice_FWJmyOjh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Dk0o5ykF_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_FWJmyOjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0lXqNiFw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0lXqNiFw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_5m6Gdztd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0lXqNiFw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_0lXqNiFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nZGIJqNM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_yDFg27R4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vJuwkTM8_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_8TApKNMQ, 0, m, &cIf_8TApKNMQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_8TApKNMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_OgprifC6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_8rk3tDV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_o9imtsMR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_uLS7OAFh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_lwxy6Uut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_T1fwXGj5, HV_BINOP_POW, 0, m, &cBinop_T1fwXGj5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_T1fwXGj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Sc3EkTo3, 0, m, &cIf_Sc3EkTo3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_foYTlWgr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_NpHZf2dB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DTUkMjXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_aDRsiYDI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DMuOCqgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8rk3tDV6, 0, m, &cIf_8rk3tDV6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aDRsiYDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8rk3tDV6, 1, m, &cIf_8rk3tDV6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uLS7OAFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_foYTlWgr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_o9imtsMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Sc3EkTo3, 0, m, &cIf_Sc3EkTo3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NpHZf2dB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T1fwXGj5, HV_BINOP_POW, 1, m, &cBinop_T1fwXGj5_sendMessage);
  cMsg_lwxy6Uut_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_Sc3EkTo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_S0eUwEr0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_vJuwkTM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8TApKNMQ, 1, m, &cIf_8TApKNMQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OgprifC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9FL4FEFY, HV_BINOP_GREATER_THAN, 1, m, &cBinop_9FL4FEFY_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gLyk1x7Y, HV_BINOP_EQ, 1, m, &cBinop_gLyk1x7Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yTEC7uB6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NjUscC5e, HV_BINOP_ADD, 0, m, &cBinop_NjUscC5e_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NjUscC5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DTUkMjXq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DMuOCqgm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9FL4FEFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Sc3EkTo3, 1, m, &cIf_Sc3EkTo3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gLyk1x7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XAyzpxSJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_XAyzpxSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_S0eUwEr0, m);
}

void Heavy_WSTD_DL3Y::cCast_k1PtiV2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yTEC7uB6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_u1HoiWbK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yDFg27R4, 0, m, &cVar_yDFg27R4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_MzEc5FdI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NjUscC5e, HV_BINOP_ADD, 1, m, &cBinop_NjUscC5e_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9FL4FEFY, HV_BINOP_GREATER_THAN, 0, m, &cBinop_9FL4FEFY_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gLyk1x7Y, HV_BINOP_EQ, 0, m, &cBinop_gLyk1x7Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_auww2T16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9USZFTIr_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Owu6Dx3s, 0, m, &cIf_Owu6Dx3s_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_Owu6Dx3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kCm2xqgD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_nTeD2w7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_0DFWxnR3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_TFMxqOh2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_GfFrvjdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BmtVcjmq, HV_BINOP_POW, 0, m, &cBinop_BmtVcjmq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BmtVcjmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PEGGxd6B, 0, m, &cIf_PEGGxd6B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XQdx5ttD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_jxxu4Jq7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VdPhmJgv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_O3rtE4Mh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ReLxq0vY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nTeD2w7d, 0, m, &cIf_nTeD2w7d_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_O3rtE4Mh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nTeD2w7d, 1, m, &cIf_nTeD2w7d_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TFMxqOh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_XQdx5ttD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0DFWxnR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_PEGGxd6B, 0, m, &cIf_PEGGxd6B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jxxu4Jq7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BmtVcjmq, HV_BINOP_POW, 1, m, &cBinop_BmtVcjmq_sendMessage);
  cMsg_GfFrvjdc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_PEGGxd6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kKjr7i0p_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7DvYKDXt_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_yPplPidC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_9USZFTIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Owu6Dx3s, 1, m, &cIf_Owu6Dx3s_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kCm2xqgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8UWR4egV, HV_BINOP_GREATER_THAN, 1, m, &cBinop_8UWR4egV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SlH4dacf, HV_BINOP_EQ, 1, m, &cBinop_SlH4dacf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1riO8Nio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dOGUpozm, HV_BINOP_ADD, 0, m, &cBinop_dOGUpozm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dOGUpozm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VdPhmJgv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ReLxq0vY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8UWR4egV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PEGGxd6B, 1, m, &cIf_PEGGxd6B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SlH4dacf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1WK4XJ78_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_1WK4XJ78_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kKjr7i0p_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7DvYKDXt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_yPplPidC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nDPoAS7e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dOGUpozm, HV_BINOP_ADD, 1, m, &cBinop_dOGUpozm_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8UWR4egV, HV_BINOP_GREATER_THAN, 0, m, &cBinop_8UWR4egV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SlH4dacf, HV_BINOP_EQ, 0, m, &cBinop_SlH4dacf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fSikGLSB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_auww2T16, 0, m, &cVar_auww2T16_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7tRsEvBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1riO8Nio_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_jirMLA57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_eGtbBK2k_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_2nvzcbCy, 0, m, &cIf_2nvzcbCy_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_2nvzcbCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ajvbW9y1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_8cVJOhun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_rEvvcATp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_qpzTjwaU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_2zmvEp7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zo9z1Y44, HV_BINOP_POW, 0, m, &cBinop_Zo9z1Y44_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Zo9z1Y44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yf8cLiYb, 0, m, &cIf_yf8cLiYb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7j0JpTPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_OtxvsUOT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LmpUnqKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_SZSka280_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_feeQglKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8cVJOhun, 0, m, &cIf_8cVJOhun_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SZSka280_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8cVJOhun, 1, m, &cIf_8cVJOhun_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qpzTjwaU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_7j0JpTPe_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rEvvcATp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_yf8cLiYb, 0, m, &cIf_yf8cLiYb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OtxvsUOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zo9z1Y44, HV_BINOP_POW, 1, m, &cBinop_Zo9z1Y44_sendMessage);
  cMsg_2zmvEp7h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_yf8cLiYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_VmCXx4sK, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_eGtbBK2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2nvzcbCy, 1, m, &cIf_2nvzcbCy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ajvbW9y1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DJfV948L, HV_BINOP_GREATER_THAN, 1, m, &cBinop_DJfV948L_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6U9ncUyT, HV_BINOP_EQ, 1, m, &cBinop_6U9ncUyT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qZGKAiYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_o84l534R, HV_BINOP_ADD, 0, m, &cBinop_o84l534R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_o84l534R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LmpUnqKB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_feeQglKc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DJfV948L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yf8cLiYb, 1, m, &cIf_yf8cLiYb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6U9ncUyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xHSTTxp5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_xHSTTxp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_VmCXx4sK, m);
}

void Heavy_WSTD_DL3Y::cCast_ldpr0kks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qZGKAiYR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_cMcRBGNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o84l534R, HV_BINOP_ADD, 1, m, &cBinop_o84l534R_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DJfV948L, HV_BINOP_GREATER_THAN, 0, m, &cBinop_DJfV948L_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6U9ncUyT, HV_BINOP_EQ, 0, m, &cBinop_6U9ncUyT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_h57Al3Q3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jirMLA57, 0, m, &cVar_jirMLA57_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_MXT6gXfG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_uYRUIAgJ, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_x006GSyT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RFHL6C1R, 0, m, &cSlice_RFHL6C1R_sendMessage);
      break;
    }
    default: {
      cSwitchcase_fXMhdGrf_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_RFHL6C1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ZU6jjiiL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ZU6jjiiL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_pkEFZkkX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZU6jjiiL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ZU6jjiiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_h2Em4w1r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_fXMhdGrf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0lSMf5i1, 0, m, &cSlice_0lSMf5i1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_gQGNZMVS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_0lSMf5i1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JB2jjnAx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JB2jjnAx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_BizChS8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JB2jjnAx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_JB2jjnAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ktWlRPnp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Dk0o5ykF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AxWOa4E1, 0, m, &cSlice_AxWOa4E1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_uuug1OQd_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_AxWOa4E1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Nqw7itZd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Nqw7itZd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_6QGPj3hb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Nqw7itZd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Nqw7itZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kzo7MmnU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_uuug1OQd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HpYfzDja, 0, m, &cSlice_HpYfzDja_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_HpYfzDja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4g1hnMCP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4g1hnMCP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_jQHhTPcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4g1hnMCP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_4g1hnMCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Af8HtmiZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_VpYNQktn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LIDv6rIS, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_0DlhRz99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8c5FyQkv, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_L0dGCPKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PbvHOSk1, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_4wXDetrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XCUWjx2u, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_6oluEVR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_U56XjQpm, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ApdyNQB4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_z43ri5oL_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_z43ri5oL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UEKzBeOU, HV_BINOP_DIVIDE, 1, m, &cBinop_UEKzBeOU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LL8QY0dh_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_upGpTbZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_8okxaFI8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uh1oLDzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_upGpTbZv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8okxaFI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UEKzBeOU, HV_BINOP_DIVIDE, 0, m, &cBinop_UEKzBeOU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LL8QY0dh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uh1oLDzM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_UEKzBeOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JjrknCMR, HV_BINOP_MULTIPLY, 1, m, &cBinop_JjrknCMR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JjrknCMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uVBYIdLT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lY6B5bvl_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_RRkGRBO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WtmWG5M0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_qSNQNaJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uWsjNXiq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_k9VBkSiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_9JRFu9tu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9JRFu9tu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JjrknCMR, HV_BINOP_MULTIPLY, 0, m, &cBinop_JjrknCMR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ek524lRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_AtpQXSkm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AtpQXSkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DEr23kW1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PfFyAamN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_V5js6U9P, 1, m, &cVar_V5js6U9P_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_V5js6U9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JRrd5VBy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_mR0tMaF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_On9ylkws, HV_BINOP_MULTIPLY, 1, m, &cBinop_On9ylkws_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_s3c7vwoI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_mR0tMaF4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_A7PMMXlc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_0wlGWU2j_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0wlGWU2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CzIsdB9w, HV_BINOP_MULTIPLY, 1, m, &cBinop_CzIsdB9w_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_96XjOt5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qcxSvOR8, HV_BINOP_MULTIPLY, 1, m, &cBinop_qcxSvOR8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rsj4Pwyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_96XjOt5M_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JhT9CRER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6wT5HNEk, HV_BINOP_MULTIPLY, 1, m, &cBinop_6wT5HNEk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TPjmMgV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tXXyrha4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tXXyrha4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D8Mm8zkV, HV_BINOP_MULTIPLY, 1, m, &cBinop_D8Mm8zkV_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_fEiru1KC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cRlW5MII_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_k9VBkSiH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ga4y2JvB_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Rtm0UQLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_ek524lRr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_uVBYIdLT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_RRkGRBO2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lY6B5bvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_qSNQNaJX_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_WtmWG5M0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eVVFJLDm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_uWsjNXiq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3F9ooVLF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_EdyPpSzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZYEkmImP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_DEr23kW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_t9mcjfzo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t9mcjfzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5HAg9387, HV_BINOP_MULTIPLY, 1, m, &cBinop_5HAg9387_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5HAg9387_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_GoNShmnp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GoNShmnp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EdyPpSzR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_JRrd5VBy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_MFsFz395_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MFsFz395_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ofBD8oej_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xHvm6gmI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v244zbmV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FoCczUQh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SXPuqzqF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AiZHduwg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_On9ylkws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VpYNQktn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_CzIsdB9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0DlhRz99_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_qcxSvOR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L0dGCPKp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_6wT5HNEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4wXDetrf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_D8Mm8zkV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6oluEVR5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_SKhTaXap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fEiru1KC, 0, m, &cVar_fEiru1KC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hVKLtzj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Rtm0UQLR, 1, m, &cVar_Rtm0UQLR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FoCczUQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qcxSvOR8, HV_BINOP_MULTIPLY, 0, m, &cBinop_qcxSvOR8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_v244zbmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6wT5HNEk, HV_BINOP_MULTIPLY, 0, m, &cBinop_6wT5HNEk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xHvm6gmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D8Mm8zkV, HV_BINOP_MULTIPLY, 0, m, &cBinop_D8Mm8zkV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SXPuqzqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CzIsdB9w, HV_BINOP_MULTIPLY, 0, m, &cBinop_CzIsdB9w_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ofBD8oej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_AiZHduwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_On9ylkws, HV_BINOP_MULTIPLY, 0, m, &cBinop_On9ylkws_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Ga4y2JvB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_V5js6U9P, 0, m, &cVar_V5js6U9P_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cRlW5MII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Rtm0UQLR, 0, m, &cVar_Rtm0UQLR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uT52yW9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wDt7bXSi, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_EsDtr3aY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0bWLbtcK, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_2k4zYIep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XSNUAFuL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Nw72WBMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8J6NmQYB, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_zLnih9ma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6dSDuFyJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_6dSDuFyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DXuoYWi4, HV_BINOP_DIVIDE, 1, m, &cBinop_DXuoYWi4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IZGEXjF1_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_pPC9dkZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_jZlrnrLX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PKmle46k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_pPC9dkZA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jZlrnrLX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DXuoYWi4, HV_BINOP_DIVIDE, 0, m, &cBinop_DXuoYWi4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_IZGEXjF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PKmle46k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_DXuoYWi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_digXPp0A, HV_BINOP_MULTIPLY, 1, m, &cBinop_digXPp0A_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_digXPp0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hNOvbO8m_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5I2qhmCK_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_oMDbD0lV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_L5DL7884_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_yfBHc09f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_e9mIphmZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_tHQn1LZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_0HtrQYNb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0HtrQYNb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_digXPp0A, HV_BINOP_MULTIPLY, 0, m, &cBinop_digXPp0A_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sheDqOW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_RquiUYbL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RquiUYbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xK7yXktn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vbR39qIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4HdN6Ywy, HV_BINOP_MULTIPLY, 1, m, &cBinop_4HdN6Ywy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1QgDYuiU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5XEOEXpX, 1, m, &cVar_5XEOEXpX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rn1A3Xzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XX4YmjCL, HV_BINOP_MULTIPLY, 1, m, &cBinop_XX4YmjCL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BZ4d6vzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_cpXTcSdX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cpXTcSdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LukmkSMF, HV_BINOP_MULTIPLY, 1, m, &cBinop_LukmkSMF_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_5XEOEXpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HiOUOHok_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_JyomrtGA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_enSa6NY2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_tHQn1LZM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pA6Yd2LX_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_UEhGpAyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_sheDqOW8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hNOvbO8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_oMDbD0lV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5I2qhmCK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_yfBHc09f_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_L5DL7884_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QJvfupdR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_e9mIphmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qwrRXovp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Ky7NYH2K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cW44edgK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_xK7yXktn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_1VUoSa5l_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1VUoSa5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2VqbExI0, HV_BINOP_MULTIPLY, 1, m, &cBinop_2VqbExI0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2VqbExI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_I7Ozt3UH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_I7Ozt3UH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ky7NYH2K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_HiOUOHok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_n6UacRyd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_n6UacRyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ecnh4Gh7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yBeesi0z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f425nK9W_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9QVTsTrY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pgFDMQfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uT52yW9U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_4HdN6Ywy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EsDtr3aY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_XX4YmjCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2k4zYIep_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_LukmkSMF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Nw72WBMZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_xuAj83FN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JyomrtGA, 0, m, &cVar_JyomrtGA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NkG2GKQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UEhGpAyP, 1, m, &cVar_UEhGpAyP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pA6Yd2LX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5XEOEXpX, 0, m, &cVar_5XEOEXpX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_enSa6NY2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UEhGpAyP, 0, m, &cVar_UEhGpAyP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9QVTsTrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pgFDMQfY, HV_BINOP_MULTIPLY, 0, m, &cBinop_pgFDMQfY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_f425nK9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4HdN6Ywy, HV_BINOP_MULTIPLY, 0, m, &cBinop_4HdN6Ywy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yBeesi0z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XX4YmjCL, HV_BINOP_MULTIPLY, 0, m, &cBinop_XX4YmjCL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ecnh4Gh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LukmkSMF, HV_BINOP_MULTIPLY, 0, m, &cBinop_LukmkSMF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cLBdVl0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bPYfoZpj, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_rC0omf33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qHd4PwFf, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_UdeoWxxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_40QdUzT9, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_uqpuCsbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GJKuPn86, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_xsS9Kxi6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9O6WBTve, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_eMwVlXgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dvZEg0kz_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_dvZEg0kz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DcoR3avz, HV_BINOP_DIVIDE, 1, m, &cBinop_DcoR3avz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IKXmdIAz_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_ecAmIvnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_q9FL2rtN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eOoEE8ut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_ecAmIvnd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_q9FL2rtN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DcoR3avz, HV_BINOP_DIVIDE, 0, m, &cBinop_DcoR3avz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_IKXmdIAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eOoEE8ut_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_DcoR3avz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UneegEgm, HV_BINOP_MULTIPLY, 1, m, &cBinop_UneegEgm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UneegEgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_et2B2cvz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3pFSqaas_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_P4PYAXG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1Wen2bxv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_HHypCtac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YtPxJQPO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PjHPRizQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_iNiSTPlx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iNiSTPlx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UneegEgm, HV_BINOP_MULTIPLY, 0, m, &cBinop_UneegEgm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GWFjwF2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_GxUCDAL0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GxUCDAL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_37SC6TRg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ao8qCfek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4ZZnkq5i, HV_BINOP_MULTIPLY, 1, m, &cBinop_4ZZnkq5i_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_R5Jp8Xbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_c1te4eZp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_c1te4eZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ao8qCfek_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zKUjE8Kk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Z0mZ2BBH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Z0mZ2BBH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PqFN7w4S, HV_BINOP_MULTIPLY, 1, m, &cBinop_PqFN7w4S_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nopQW53q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rXfvAINm, HV_BINOP_MULTIPLY, 1, m, &cBinop_rXfvAINm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0jbsYLn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5yWyxwam_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5yWyxwam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_nopQW53q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DVoc4jLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2WHNfc2J, 1, m, &cVar_2WHNfc2J_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_03Gu1DV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tb8HFi3b, HV_BINOP_MULTIPLY, 1, m, &cBinop_Tb8HFi3b_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DPstbrA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_L8Ydzqvg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_L8Ydzqvg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9qlDJ67J, HV_BINOP_MULTIPLY, 1, m, &cBinop_9qlDJ67J_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_2WHNfc2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WQjpv0zc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_g3Z234Yo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4LkBh3Z1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_PjHPRizQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WglFGbI6_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_bJNgaoqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_GWFjwF2d_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3pFSqaas_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_HHypCtac_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_et2B2cvz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_P4PYAXG3_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_1Wen2bxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_quAKfBBL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_YtPxJQPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_oiH93lti_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_zFWMpZLz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KIjt0MyX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_37SC6TRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_J9J1bTdc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_J9J1bTdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gZset3dE, HV_BINOP_MULTIPLY, 1, m, &cBinop_gZset3dE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gZset3dE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_P8naz7bW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_P8naz7bW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zFWMpZLz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_WQjpv0zc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_edx71H1f_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_edx71H1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l7ZUzkNm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GQyh2zv6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PdswVDKV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2leDtvMp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KSZSgNyT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sRc4EFAx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4ZZnkq5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cLBdVl0y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PqFN7w4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rC0omf33_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_rXfvAINm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UdeoWxxm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Tb8HFi3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uqpuCsbe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_9qlDJ67J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xsS9Kxi6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_rpzKSpkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bJNgaoqZ, 1, m, &cVar_bJNgaoqZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_IitMcwji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_g3Z234Yo, 0, m, &cVar_g3Z234Yo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_l7ZUzkNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_PdswVDKV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tb8HFi3b, HV_BINOP_MULTIPLY, 0, m, &cBinop_Tb8HFi3b_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sRc4EFAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4ZZnkq5i, HV_BINOP_MULTIPLY, 0, m, &cBinop_4ZZnkq5i_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GQyh2zv6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9qlDJ67J, HV_BINOP_MULTIPLY, 0, m, &cBinop_9qlDJ67J_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2leDtvMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rXfvAINm, HV_BINOP_MULTIPLY, 0, m, &cBinop_rXfvAINm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KSZSgNyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PqFN7w4S, HV_BINOP_MULTIPLY, 0, m, &cBinop_PqFN7w4S_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4LkBh3Z1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bJNgaoqZ, 0, m, &cVar_bJNgaoqZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WglFGbI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2WHNfc2J, 0, m, &cVar_2WHNfc2J_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kKjr7i0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MXT6gXfG, 1, m, &cIf_MXT6gXfG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wSEmz01p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_uYRUIAgJ, m);
}

void Heavy_WSTD_DL3Y::cBinop_7DvYKDXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wSEmz01p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_yPplPidC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MXT6gXfG, 0, m, &cIf_MXT6gXfG_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_u74aEXE0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LiQn4QYc, 0, m, &cSlice_LiQn4QYc_sendMessage);
      break;
    }
    default: {
      cSwitchcase_T2Ivnw8u_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_LiQn4QYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_YngD4aPm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_YngD4aPm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_PIw5c6QT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YngD4aPm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_YngD4aPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3qn6oHRv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_jTYRqwER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_WbXO6vGu_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_tmRn2FdH, 0, m, &cIf_tmRn2FdH_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_tmRn2FdH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_z6zfj83q_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_CZIcHgqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_1IZDqtdW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_pKXl3Qdo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_dX2NrD69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qSyYKezB, HV_BINOP_POW, 0, m, &cBinop_qSyYKezB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qSyYKezB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6kkpEglA, 0, m, &cIf_6kkpEglA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pDeR31De_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_uiBPiOTS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_A0H0erQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_lrTognDV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vqUVDDwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CZIcHgqa, 0, m, &cIf_CZIcHgqa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lrTognDV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CZIcHgqa, 1, m, &cIf_CZIcHgqa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pKXl3Qdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_pDeR31De_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1IZDqtdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_6kkpEglA, 0, m, &cIf_6kkpEglA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uiBPiOTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qSyYKezB, HV_BINOP_POW, 1, m, &cBinop_qSyYKezB_sendMessage);
  cMsg_dX2NrD69_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_6kkpEglA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_PJYDr6jw, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_WbXO6vGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tmRn2FdH, 1, m, &cIf_tmRn2FdH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_z6zfj83q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_onebWDZj, HV_BINOP_GREATER_THAN, 1, m, &cBinop_onebWDZj_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pqEizlIo, HV_BINOP_EQ, 1, m, &cBinop_pqEizlIo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kXndEnSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oXiZdQSz, HV_BINOP_ADD, 0, m, &cBinop_oXiZdQSz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oXiZdQSz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A0H0erQL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vqUVDDwj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_onebWDZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6kkpEglA, 1, m, &cIf_6kkpEglA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pqEizlIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H2xNaqVd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_H2xNaqVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_PJYDr6jw, m);
}

void Heavy_WSTD_DL3Y::cCast_OS3EHFNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kXndEnSv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_B7pZIGZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oXiZdQSz, HV_BINOP_ADD, 1, m, &cBinop_oXiZdQSz_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_onebWDZj, HV_BINOP_GREATER_THAN, 0, m, &cBinop_onebWDZj_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pqEizlIo, HV_BINOP_EQ, 0, m, &cBinop_pqEizlIo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_O9KSZ0PN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jTYRqwER, 0, m, &cVar_jTYRqwER_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_5b0RviJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_P3SqzP4b_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ml2IWbQI, 0, m, &cIf_ml2IWbQI_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_ml2IWbQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_mB56kM3b_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_HFQI8wiG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_bFECyTB5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_mhdrU0dT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_0gtbBd5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7QE5iK4T, HV_BINOP_POW, 0, m, &cBinop_7QE5iK4T_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7QE5iK4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Bj3PARrF, 0, m, &cIf_Bj3PARrF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xRU83jxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_vhQmsXpr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_H3JxKPxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vOvrRztY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_H2fFUHID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HFQI8wiG, 0, m, &cIf_HFQI8wiG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vOvrRztY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HFQI8wiG, 1, m, &cIf_HFQI8wiG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mhdrU0dT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_xRU83jxJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bFECyTB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Bj3PARrF, 0, m, &cIf_Bj3PARrF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vhQmsXpr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7QE5iK4T, HV_BINOP_POW, 1, m, &cBinop_7QE5iK4T_sendMessage);
  cMsg_0gtbBd5I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_Bj3PARrF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_IBdQzReW_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yEVREX4w_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_KjetbQVR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_P3SqzP4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ml2IWbQI, 1, m, &cIf_ml2IWbQI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mB56kM3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EkYhEv2U, HV_BINOP_GREATER_THAN, 1, m, &cBinop_EkYhEv2U_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_J3dyNbNP, HV_BINOP_EQ, 1, m, &cBinop_J3dyNbNP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UmmjBqO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OABMlurd, HV_BINOP_ADD, 0, m, &cBinop_OABMlurd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OABMlurd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H3JxKPxO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H2fFUHID_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EkYhEv2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Bj3PARrF, 1, m, &cIf_Bj3PARrF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_J3dyNbNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mXMzn4kh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_mXMzn4kh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_IBdQzReW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yEVREX4w_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_KjetbQVR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5KiLt1GQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UmmjBqO8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_hKVdy9ns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OABMlurd, HV_BINOP_ADD, 1, m, &cBinop_OABMlurd_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EkYhEv2U, HV_BINOP_GREATER_THAN, 0, m, &cBinop_EkYhEv2U_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_J3dyNbNP, HV_BINOP_EQ, 0, m, &cBinop_J3dyNbNP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Q2FWroVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5b0RviJn, 0, m, &cVar_5b0RviJn_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_v9DOjPkW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_eAmSlTnn_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_sfKbcfzg, 0, m, &cIf_sfKbcfzg_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_sfKbcfzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_JGtmFKuz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_mlb1ktYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ClaW7I3a_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_GRn9L3ws_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_pR1se9Dn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8GddyK3u, HV_BINOP_POW, 0, m, &cBinop_8GddyK3u_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8GddyK3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eAWdD2YT, 0, m, &cIf_eAWdD2YT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PSul3jhk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_8MfnMmRd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vwqTsCUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mFK5RVYk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7PiHkM7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mlb1ktYC, 0, m, &cIf_mlb1ktYC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mFK5RVYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mlb1ktYC, 1, m, &cIf_mlb1ktYC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GRn9L3ws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_PSul3jhk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ClaW7I3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_eAWdD2YT, 0, m, &cIf_eAWdD2YT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8MfnMmRd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8GddyK3u, HV_BINOP_POW, 1, m, &cBinop_8GddyK3u_sendMessage);
  cMsg_pR1se9Dn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_eAWdD2YT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Dr4Eayap, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_eAmSlTnn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sfKbcfzg, 1, m, &cIf_sfKbcfzg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JGtmFKuz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uAmgZGXg, HV_BINOP_GREATER_THAN, 1, m, &cBinop_uAmgZGXg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9ddss8aB, HV_BINOP_EQ, 1, m, &cBinop_9ddss8aB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7EQbWBeG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_B34wWSAd, HV_BINOP_ADD, 0, m, &cBinop_B34wWSAd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_B34wWSAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vwqTsCUJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7PiHkM7Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uAmgZGXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eAWdD2YT, 1, m, &cIf_eAWdD2YT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9ddss8aB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FiBLfksZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_FiBLfksZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Dr4Eayap, m);
}

void Heavy_WSTD_DL3Y::cCast_80q1DJjl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7EQbWBeG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_c8AHIEGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B34wWSAd, HV_BINOP_ADD, 1, m, &cBinop_B34wWSAd_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uAmgZGXg, HV_BINOP_GREATER_THAN, 0, m, &cBinop_uAmgZGXg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9ddss8aB, HV_BINOP_EQ, 0, m, &cBinop_9ddss8aB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6L8VYv5q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_v9DOjPkW, 0, m, &cVar_v9DOjPkW_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_G5BuEctb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_l0HWETlD, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_SPj4ZmFG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_stLoRWaF, 0, m, &cSlice_stLoRWaF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_1zsPKXSR_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_stLoRWaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GnMmIWge_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GnMmIWge_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_f3nIbJFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GnMmIWge_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_GnMmIWge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_q8p8jqyl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_1zsPKXSR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rKY19Nsv, 0, m, &cSlice_rKY19Nsv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_u74aEXE0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_rKY19Nsv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UkCgj9ht_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UkCgj9ht_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_qWRbiOJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UkCgj9ht_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_UkCgj9ht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hexPoHfL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_T2Ivnw8u_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1WDwr2P9, 0, m, &cSlice_1WDwr2P9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_kNGmDnv6_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_1WDwr2P9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_lIUsoyAc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_lIUsoyAc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_PxlzcX9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lIUsoyAc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_lIUsoyAc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pPiQGzox_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_kNGmDnv6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tiMvmVg7, 0, m, &cSlice_tiMvmVg7_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_tiMvmVg7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rx2kB8Qb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rx2kB8Qb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_H0CEWVNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rx2kB8Qb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_rx2kB8Qb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4yZXA2n7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_iJzpHx8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UeaU7bYE, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_aaGydNog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xbmhxYlF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_wOx1JY2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JZcuUAUV, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_8pGAuZYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7bGU525l, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Fbj3P55Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M1L1t4eY, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_YJXVL6d4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_19aCrVXN_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_19aCrVXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2pDn2mMA, HV_BINOP_DIVIDE, 1, m, &cBinop_2pDn2mMA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yKnqHoJH_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_OzpBySmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Gv99eyRo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BuWqvF5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_OzpBySmU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Gv99eyRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2pDn2mMA, HV_BINOP_DIVIDE, 0, m, &cBinop_2pDn2mMA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yKnqHoJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BuWqvF5i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2pDn2mMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QBXaos29, HV_BINOP_MULTIPLY, 1, m, &cBinop_QBXaos29_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QBXaos29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Dcqcd1Hq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fi632ixh_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_pjwbKE5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_h7UKcZZy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_HQQhB4vM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SurnzwL4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_3P8MmptY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_uFvSnU9K_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uFvSnU9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QBXaos29, HV_BINOP_MULTIPLY, 0, m, &cBinop_QBXaos29_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_F4SXfXi0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_nlS5JZyN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nlS5JZyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hPOYEUIi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_pvuTkNgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uEFMghIh, 1, m, &cVar_uEFMghIh_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_uEFMghIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1JyARRv4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_EKeJITbZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MjFtpEVO, HV_BINOP_MULTIPLY, 1, m, &cBinop_MjFtpEVO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KChntuKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EKeJITbZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VR41Gm6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Or6c8OVp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Or6c8OVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cUlZ10Tb, HV_BINOP_MULTIPLY, 1, m, &cBinop_cUlZ10Tb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4bNTF0ur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7TYIvE8A, HV_BINOP_MULTIPLY, 1, m, &cBinop_7TYIvE8A_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_krlOGGUS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4bNTF0ur_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RqtGF8Gp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c9cLPSbT, HV_BINOP_MULTIPLY, 1, m, &cBinop_c9cLPSbT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ws3puxCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_sGH6eKx3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sGH6eKx3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_82NdA0G9, HV_BINOP_MULTIPLY, 1, m, &cBinop_82NdA0G9_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_7zyL7ajd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BQ8J4o6W_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_3P8MmptY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pNGAeFkj_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_e3GOrZS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_F4SXfXi0_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Fi632ixh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_HQQhB4vM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Dcqcd1Hq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_pjwbKE5X_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_h7UKcZZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VbMm6jGb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_SurnzwL4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BotDdeNS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_4EeuWQKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jZRZbRDn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_hPOYEUIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_tzLKubn6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tzLKubn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MEP31SrZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_MEP31SrZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MEP31SrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SNF7ZoQg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SNF7ZoQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4EeuWQKd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_1JyARRv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_5PF4BUVu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5PF4BUVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4tcVpv4P_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HsK9OejY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jaDxJbAf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aZLo7ZlZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wygb8KfY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DkgqVTqb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MjFtpEVO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iJzpHx8o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_cUlZ10Tb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aaGydNog_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_7TYIvE8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wOx1JY2E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_c9cLPSbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8pGAuZYK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_82NdA0G9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fbj3P55Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ovVw2GQN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e3GOrZS4, 1, m, &cVar_e3GOrZS4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_e0w3iiJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7zyL7ajd, 0, m, &cVar_7zyL7ajd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4tcVpv4P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_jaDxJbAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c9cLPSbT, HV_BINOP_MULTIPLY, 0, m, &cBinop_c9cLPSbT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aZLo7ZlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7TYIvE8A, HV_BINOP_MULTIPLY, 0, m, &cBinop_7TYIvE8A_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wygb8KfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cUlZ10Tb, HV_BINOP_MULTIPLY, 0, m, &cBinop_cUlZ10Tb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HsK9OejY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_82NdA0G9, HV_BINOP_MULTIPLY, 0, m, &cBinop_82NdA0G9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DkgqVTqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MjFtpEVO, HV_BINOP_MULTIPLY, 0, m, &cBinop_MjFtpEVO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pNGAeFkj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uEFMghIh, 0, m, &cVar_uEFMghIh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BQ8J4o6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e3GOrZS4, 0, m, &cVar_e3GOrZS4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JHnXHvTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_T8plHKWI, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_v0IF8ACD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qrKWxgpH, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_clarBAAk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Z5wR9mNX, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_qDDI3nsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XbTx5iqZ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_abubRSFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PSrADIAk_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_PSrADIAk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NaikdOpl, HV_BINOP_DIVIDE, 1, m, &cBinop_NaikdOpl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fh8KNjBm_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_vRKtwX5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Z7lemACX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_R3lyHTAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_vRKtwX5P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Z7lemACX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NaikdOpl, HV_BINOP_DIVIDE, 0, m, &cBinop_NaikdOpl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fh8KNjBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R3lyHTAP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_NaikdOpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_31cXL69M, HV_BINOP_MULTIPLY, 1, m, &cBinop_31cXL69M_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_31cXL69M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zEjogCft_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TFgnj2g9_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_RuWoHV5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TyUjZnPa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_rXknZH0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hvZoY96V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zJfZeJxS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_oqvkl2Tp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oqvkl2Tp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_31cXL69M, HV_BINOP_MULTIPLY, 0, m, &cBinop_31cXL69M_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sU42qCTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ioN4nqzx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ioN4nqzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sxCIKnDf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_SQBwvIVA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d7Oa4JFv, HV_BINOP_MULTIPLY, 1, m, &cBinop_d7Oa4JFv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_su5XuWft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gUO2UQel, 1, m, &cVar_gUO2UQel_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2Pqxnui5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DWXHqoqu, HV_BINOP_MULTIPLY, 1, m, &cBinop_DWXHqoqu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZcJ0LNvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Arma5n9q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Arma5n9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HbwDUTE2, HV_BINOP_MULTIPLY, 1, m, &cBinop_HbwDUTE2_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_gUO2UQel_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J1Qu957V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_eyQEDmhc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Uib1uFgn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_zJfZeJxS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eXvqqd4h_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_mQz0k6M2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_sU42qCTW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TFgnj2g9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_rXknZH0K_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zEjogCft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_RuWoHV5n_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_TyUjZnPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AdP0OpFx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_hvZoY96V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8XKCNsZT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_bAJ3ZL6F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ewyCV9dM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_sxCIKnDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_IacA7vWU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IacA7vWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z95C3egD, HV_BINOP_MULTIPLY, 1, m, &cBinop_Z95C3egD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Z95C3egD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8i5ia3FV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8i5ia3FV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bAJ3ZL6F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_J1Qu957V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_6wFxiw4n_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6wFxiw4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4ktareS6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6RUZ4OJM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_19Bt0n1l_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PRKUGRAp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FiPlHaay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JHnXHvTJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_d7Oa4JFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v0IF8ACD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_DWXHqoqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_clarBAAk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_HbwDUTE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qDDI3nsa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_cYO22q0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eyQEDmhc, 0, m, &cVar_eyQEDmhc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_whhMxUOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mQz0k6M2, 1, m, &cVar_mQz0k6M2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_eXvqqd4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gUO2UQel, 0, m, &cVar_gUO2UQel_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Uib1uFgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mQz0k6M2, 0, m, &cVar_mQz0k6M2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4ktareS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HbwDUTE2, HV_BINOP_MULTIPLY, 0, m, &cBinop_HbwDUTE2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PRKUGRAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FiPlHaay, HV_BINOP_MULTIPLY, 0, m, &cBinop_FiPlHaay_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_19Bt0n1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d7Oa4JFv, HV_BINOP_MULTIPLY, 0, m, &cBinop_d7Oa4JFv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6RUZ4OJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DWXHqoqu, HV_BINOP_MULTIPLY, 0, m, &cBinop_DWXHqoqu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kg3ShzEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lZEgVmHV, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_M6Lsnk5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_32Ejqr3u, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_urtt3jWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6RtX3h3U, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_T3lk0tfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OxqkCC2F, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_2Pj9zS5s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0Q0OaVzy, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_HMTy0m7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hk3yShuS_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_hk3yShuS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OfwAxfuc, HV_BINOP_DIVIDE, 1, m, &cBinop_OfwAxfuc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_22gOtZSk_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_Ll6VnbJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_xfg0Ss0C_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xoFyatNo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Ll6VnbJL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xfg0Ss0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OfwAxfuc, HV_BINOP_DIVIDE, 0, m, &cBinop_OfwAxfuc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_22gOtZSk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xoFyatNo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OfwAxfuc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WfI2ozje, HV_BINOP_MULTIPLY, 1, m, &cBinop_WfI2ozje_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WfI2ozje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l87IogDT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jjOZu3wk_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_HGRLWPiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NWfeSRwm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_iQvoR8Pa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rttgOKmL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zfHZUbrq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Shpt4mm9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Shpt4mm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WfI2ozje, HV_BINOP_MULTIPLY, 0, m, &cBinop_WfI2ozje_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DhFR2YlE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_h8U4DKbW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_h8U4DKbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Nr8JF2r2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_IVujCV0f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lRUgFuSM, HV_BINOP_MULTIPLY, 1, m, &cBinop_lRUgFuSM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5T2wbPPJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_KrjsbURO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KrjsbURO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_IVujCV0f_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pyFVqKnM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_qOFBxR1b_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qOFBxR1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X6VkIiE5, HV_BINOP_MULTIPLY, 1, m, &cBinop_X6VkIiE5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TfX6WnyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H8T5j3p5, HV_BINOP_MULTIPLY, 1, m, &cBinop_H8T5j3p5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ziFFnr9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_OI5hK2VM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OI5hK2VM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_TfX6WnyD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iq1NU4vp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wG8igew4, 1, m, &cVar_wG8igew4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_evU2fuSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qh3dNMmm, HV_BINOP_MULTIPLY, 1, m, &cBinop_Qh3dNMmm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UMPlh2AO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Cb7qt7am_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Cb7qt7am_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yn6BJ4YV, HV_BINOP_MULTIPLY, 1, m, &cBinop_yn6BJ4YV_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_wG8igew4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W9Kv0Pt4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_cpJ0nrvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_biQ2Tv8h_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_zfHZUbrq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WkLEmc5G_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_BAYMWNS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_DhFR2YlE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_l87IogDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_HGRLWPiT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jjOZu3wk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_iQvoR8Pa_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_NWfeSRwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FOxKVdgZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_rttgOKmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IMKkYORq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_YYKVpc3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_R4SFKb0S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Nr8JF2r2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_oswnsbNH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oswnsbNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KPJeRpuF, HV_BINOP_MULTIPLY, 1, m, &cBinop_KPJeRpuF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KPJeRpuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cUwBF7lc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cUwBF7lc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YYKVpc3u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_W9Kv0Pt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_DTAa60Kv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DTAa60Kv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WouW9PQC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wswvdo8x_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vDHK8tNa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yWtHQC5I_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7t3uXcyt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xJZaOVLJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lRUgFuSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kg3ShzEc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_X6VkIiE5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M6Lsnk5T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_H8T5j3p5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_urtt3jWU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Qh3dNMmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T3lk0tfD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_yn6BJ4YV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2Pj9zS5s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_c4fq91gS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BAYMWNS8, 1, m, &cVar_BAYMWNS8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XpJZCdjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cpJ0nrvG, 0, m, &cVar_cpJ0nrvG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WouW9PQC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_xJZaOVLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lRUgFuSM, HV_BINOP_MULTIPLY, 0, m, &cBinop_lRUgFuSM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vDHK8tNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qh3dNMmm, HV_BINOP_MULTIPLY, 0, m, &cBinop_Qh3dNMmm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yWtHQC5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H8T5j3p5, HV_BINOP_MULTIPLY, 0, m, &cBinop_H8T5j3p5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Wswvdo8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yn6BJ4YV, HV_BINOP_MULTIPLY, 0, m, &cBinop_yn6BJ4YV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7t3uXcyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X6VkIiE5, HV_BINOP_MULTIPLY, 0, m, &cBinop_X6VkIiE5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_biQ2Tv8h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BAYMWNS8, 0, m, &cVar_BAYMWNS8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WkLEmc5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wG8igew4, 0, m, &cVar_wG8igew4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IBdQzReW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G5BuEctb, 1, m, &cIf_G5BuEctb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cl573NUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_l0HWETlD, m);
}

void Heavy_WSTD_DL3Y::cBinop_yEVREX4w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cl573NUE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_KjetbQVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G5BuEctb, 0, m, &cIf_G5BuEctb_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_7WcuRte4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Twve1onL, HV_BINOP_DIVIDE, 0, m, &cBinop_Twve1onL_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Kk1rc6QO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U97EiOEm, HV_BINOP_DIVIDE, 1, m, &cBinop_U97EiOEm_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Twve1onL, HV_BINOP_DIVIDE, 1, m, &cBinop_Twve1onL_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_57haYHmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O5u3MaAe, HV_BINOP_DIVIDE, 0, m, &cBinop_O5u3MaAe_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_QRUA112B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O5u3MaAe, HV_BINOP_DIVIDE, 1, m, &cBinop_O5u3MaAe_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TtpPTW1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U97EiOEm, HV_BINOP_DIVIDE, 0, m, &cBinop_U97EiOEm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5xrx0dqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Kk1rc6QO, 0, m, &cVar_Kk1rc6QO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_OIA2ZmPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7WcuRte4, 0, m, &cVar_7WcuRte4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_U97EiOEm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_57haYHmt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Twve1onL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_QRUA112B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_O5u3MaAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_UJ6Q0YaI_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_XWp6u4FG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_1lY4EyOV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wzJDV3ar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_GkmnCifu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UJ6Q0YaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_wzJDV3ar_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GkmnCifu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_XWp6u4FG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1lY4EyOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_po0Vb0Ry_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_FXSOmsEf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0WDF43JF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_LVL2uYbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m3dYt2Hn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_EUnyKhAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4Mi7P3UK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Q0SxFpBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_leBafhu3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_jECbaHV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AslT1nNW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_okbRqMm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZhXjAwqf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_nNNVrZty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6f6JN8oz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_VndE8skE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5BTq63wC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_oVEoaXRF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_naokMFGy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_C8V0v6Pm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JAOHPJLS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_DDpKa7gs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hSsvF2gU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_eCZxXDJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rceIHSHr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_AXaL8SNv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kRnJ4Lz3, 0, m, &cSlice_kRnJ4Lz3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_kRnJ4Lz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PVjp5GEC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PVjp5GEC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_QL8s1aHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PVjp5GEC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_PVjp5GEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_49jy3Vkg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_eNxKgRoQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AbElgA2m, 0, m, &cSlice_AbElgA2m_sendMessage);
      break;
    }
    default: {
      cSwitchcase_gc0LeHdy_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_AbElgA2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_X0pICj5O_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_X0pICj5O_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_uJ9naidV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_X0pICj5O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_X0pICj5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_G0df0oxm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_GrtOHpCT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_agz80tcb, 0, m, &cSlice_agz80tcb_sendMessage);
      break;
    }
    default: {
      cSwitchcase_AXaL8SNv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_agz80tcb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Br8CLhhT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Br8CLhhT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_9AsgeOTx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Br8CLhhT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Br8CLhhT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2ss8ImUC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OgSqSxy3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_IRXbWnOx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IRXbWnOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_GVPtjnXS_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_6GyoH6hI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Mg4vfN3Q_sendMessage(_c, 0, m);
  cMsg_bGSz3Jac_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_xA0etvVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fe079nwl_sendMessage(_c, 0, m);
  cMsg_F1h1WDnl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_GVPtjnXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_IwTmPfGb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IwTmPfGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eGEvepct_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bpPM3tFu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bpPM3tFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TTt7kOTc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_eGEvepct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_FAUdes3q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FAUdes3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9LN0xk8d_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TTt7kOTc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HRTduUpS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HRTduUpS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_nmCZAnYv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9LN0xk8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_6GyoH6hI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nmCZAnYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_xA0etvVp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TjW78xZ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_TVs6jr50_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TVs6jr50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_JpBfGDXn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JpBfGDXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_GGM8R9Mq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GGM8R9Mq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gaWB4Xnq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4QLRbyE9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4QLRbyE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8BeL0Sjo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_gaWB4Xnq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_mdXKRNor_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mdXKRNor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_TuGsQ3ja_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8BeL0Sjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_IxEFaegg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IxEFaegg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_OQa0AN8h_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OQa0AN8h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KG9dEepr_sendMessage(_c, 0, m);
  cMsg_859dlHtd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_TuGsQ3ja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jvv7OZP1_sendMessage(_c, 0, m);
  cMsg_gnpkZiPB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_sdmb10VY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_wfD4U9S3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wfD4U9S3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_JeJ1ycw4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_PIFcMA63_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_BSUpe4iS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_p68XKOEn_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_v4IviMyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4ByhyAcc_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_4ByhyAcc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7Zz9xx5I, HV_BINOP_DIVIDE, 1, m, &cBinop_7Zz9xx5I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JeJ1ycw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_y8yGOF1P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_y8yGOF1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_V0rpZrcw, m);
}

void Heavy_WSTD_DL3Y::cMsg_TCo338xp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_XjthRd0D_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XjthRd0D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_sdmb10VY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PIFcMA63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_s1XQ22LP, m);
}

void Heavy_WSTD_DL3Y::cBinop_p68XKOEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_gHGCJwfa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gHGCJwfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7Zz9xx5I, HV_BINOP_DIVIDE, 0, m, &cBinop_7Zz9xx5I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7Zz9xx5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TCo338xp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_0IfqIGK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_UZ1Fg9Zy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UZ1Fg9Zy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Huszvmkg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8x8y5v8a_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_frTSLTPQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_gPb9rWSu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_edobwPFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_soSTpyui_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_soSTpyui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SdZLZdcM, HV_BINOP_DIVIDE, 1, m, &cBinop_SdZLZdcM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Huszvmkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0mCSjCKJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0mCSjCKJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GC7HnffY, m);
}

void Heavy_WSTD_DL3Y::cMsg_DJrQaE6c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_wLssBxNr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wLssBxNr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_0IfqIGK9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8x8y5v8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_AtEVUevM, m);
}

void Heavy_WSTD_DL3Y::cBinop_gPb9rWSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_HFm2epGy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HFm2epGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SdZLZdcM, HV_BINOP_DIVIDE, 0, m, &cBinop_SdZLZdcM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SdZLZdcM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DJrQaE6c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_BwfW4ZsZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6IFRQgtm, HV_BINOP_MULTIPLY, 0, m, &cBinop_6IFRQgtm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9WRKfDc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AqGAs6IG_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_AqGAs6IG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IDsPS3Kd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_6IFRQgtm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_qsUo4V22_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lX6MkBGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6IFRQgtm, HV_BINOP_MULTIPLY, 1, m, &cBinop_6IFRQgtm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IDsPS3Kd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_lX6MkBGS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qsUo4V22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_STFFLPQy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_STFFLPQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_rCEh8mt5_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_EocdERQG, m);
}

void Heavy_WSTD_DL3Y::cBinop_rCEh8mt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_hy0hoSSq, m);
}

void Heavy_WSTD_DL3Y::cVar_NCEeNUML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iyeMHhmL, HV_BINOP_MULTIPLY, 0, m, &cBinop_iyeMHhmL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CkZtFPex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sCzaZvNm_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_sCzaZvNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EPLmWs3V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_iyeMHhmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_fCx1w6lm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MTl0TwDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iyeMHhmL, HV_BINOP_MULTIPLY, 1, m, &cBinop_iyeMHhmL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EPLmWs3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_MTl0TwDB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fCx1w6lm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_WlVHQcRo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WlVHQcRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_5CYJSJDm_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_h4MYRIoY, m);
}

void Heavy_WSTD_DL3Y::cBinop_5CYJSJDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_b4hL9Yaq, m);
}

void Heavy_WSTD_DL3Y::sEnv_hKqfr7RZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Vga53KyV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6eEe4Ir8_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_ticmwFmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_uKDHuY3U_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_KqTglL4l_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_xagh52ur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YV1Jl7wa, HV_BINOP_POW, 0, m, &cBinop_YV1Jl7wa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YV1Jl7wa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dq5PPi04_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_hxXsEvqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_jYNTfMGD_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Vga53KyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_57RVeY0E_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6eEe4Ir8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ticmwFmx, 0, m, &cIf_ticmwFmx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_57RVeY0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ticmwFmx, 1, m, &cIf_ticmwFmx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KqTglL4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_hxXsEvqo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uKDHuY3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_dq5PPi04_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_jYNTfMGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YV1Jl7wa, HV_BINOP_POW, 1, m, &cBinop_YV1Jl7wa_sendMessage);
  cMsg_xagh52ur_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_TuGilJ0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qxWc7yR9, HV_BINOP_MULTIPLY, 0, m, &cBinop_qxWc7yR9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_sE3jsw1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zLbuFPFj_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_zLbuFPFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q9sM4zM1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_qxWc7yR9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_UDKXXgUN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jsDHipk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qxWc7yR9, HV_BINOP_MULTIPLY, 1, m, &cBinop_qxWc7yR9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Q9sM4zM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_jsDHipk9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UDKXXgUN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_EIAgQJMJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EIAgQJMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_L0pJvHNj_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_opEgIqvz, m);
}

void Heavy_WSTD_DL3Y::cBinop_L0pJvHNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GFrx5vap, m);
}

void Heavy_WSTD_DL3Y::cMsg_dq5PPi04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_acNiZ16T_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_acNiZ16T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_AvuWGbS4, m);
}

void Heavy_WSTD_DL3Y::sEnv_EYHUWXKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PqKF9ltx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CCjYkwZ0_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_bMzd1Jqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_7NqDC4zC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Rud5cSxV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_fq76S6ID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rj6A0UmP, HV_BINOP_POW, 0, m, &cBinop_Rj6A0UmP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Rj6A0UmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UErslZTb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Xnabpf73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_nHJ2T6tw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PqKF9ltx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9IgF5oyv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CCjYkwZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bMzd1Jqg, 0, m, &cIf_bMzd1Jqg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9IgF5oyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bMzd1Jqg, 1, m, &cIf_bMzd1Jqg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Rud5cSxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Xnabpf73_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7NqDC4zC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_UErslZTb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_nHJ2T6tw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rj6A0UmP, HV_BINOP_POW, 1, m, &cBinop_Rj6A0UmP_sendMessage);
  cMsg_fq76S6ID_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_CpRBNaTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2i9b2eB4, HV_BINOP_MULTIPLY, 0, m, &cBinop_2i9b2eB4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NgGqzbmY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_if9szPxx_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_if9szPxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QaGSKkO3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2i9b2eB4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_cQg5J3io_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BxlJF6Xl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2i9b2eB4, HV_BINOP_MULTIPLY, 1, m, &cBinop_2i9b2eB4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QaGSKkO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_BxlJF6Xl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cQg5J3io_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_XVWzXtJB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XVWzXtJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_GUJR0Urt_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_rQ3v3kcI, m);
}

void Heavy_WSTD_DL3Y::cBinop_GUJR0Urt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ssK9RI9d, m);
}

void Heavy_WSTD_DL3Y::cMsg_UErslZTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_gzXOn9d7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gzXOn9d7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_lKvCRRI2, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_gc0LeHdy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qk68sJ50, 0, m, &cSlice_qk68sJ50_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GrtOHpCT_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_qk68sJ50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_bZdugL4X_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_bZdugL4X_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_l9w4TKoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bZdugL4X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_bZdugL4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ICcnLC2m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Nh7jF84R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_X59hNpnr_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_X59hNpnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_hMtrHWP6_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_p16THOOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_p16THOOl, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2u0eElsG, 0, m, &cDelay_2u0eElsG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_p16THOOl, 0, m, &cDelay_p16THOOl_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9Hqwy0um, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_2u0eElsG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2u0eElsG, m);
  cMsg_oPEErLQT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_0qSH7HiO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_STopkYm6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_XYAVrj1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1RrUMjq8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_pvg37Ach_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GOxyZt14_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_p16THOOl, 2, m, &cDelay_p16THOOl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dV6XSw6X_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1RrUMjq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_pvg37Ach, 0, m, &hTable_pvg37Ach_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hMtrHWP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_XYAVrj1B_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oPEErLQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_pvg37Ach, 0, m, &hTable_pvg37Ach_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dV6XSw6X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_p16THOOl, 0, m, &cDelay_p16THOOl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GOxyZt14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_2u0eElsG, 2, m, &cDelay_2u0eElsG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_STopkYm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9Hqwy0um, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_rf4irwnQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y8qnviG0, HV_BINOP_SUBTRACT, 0, m, &cBinop_y8qnviG0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mwNhCIfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fgScjLb3_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_fgScjLb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_IO9QcYTf_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_yrTI7bzk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3Rrr0OFJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_kqpoCzMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kqpoCzMa, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_q755FTMM, 0, m, &cDelay_q755FTMM_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_NZ1VWvZz, 0, m, &sTabread_NZ1VWvZz_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_q755FTMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_q755FTMM, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_NZ1VWvZz, 0, m, &sTabread_NZ1VWvZz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_q755FTMM, 0, m, &cDelay_q755FTMM_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_NZ1VWvZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Ls58UR87, HV_BINOP_SUBTRACT, 0, m, &cBinop_Ls58UR87_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_sIjZ187J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ckL2brDp, HV_BINOP_MAX, 0, m, &cBinop_ckL2brDp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IO9QcYTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sIjZ187J, HV_BINOP_MULTIPLY, 0, m, &cBinop_sIjZ187J_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_y8qnviG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZlIvZ2zS_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_NZ1VWvZz, 0, m, &sTabread_NZ1VWvZz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Hfj9teSl_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_TheSBOz1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ls58UR87, HV_BINOP_SUBTRACT, 1, m, &cBinop_Ls58UR87_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_q755FTMM, 2, m, &cDelay_q755FTMM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3Rrr0OFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_TheSBOz1_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZlIvZ2zS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_kqpoCzMa, 0, m, &cDelay_kqpoCzMa_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_q755FTMM, 0, m, &cDelay_q755FTMM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_L19streG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_ckL2brDp, HV_BINOP_MAX, 1, m, &cBinop_ckL2brDp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ckL2brDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y8qnviG0, HV_BINOP_SUBTRACT, 1, m, &cBinop_y8qnviG0_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Hfj9teSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kqpoCzMa, 0, m, &cDelay_kqpoCzMa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Z9JkdeHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kqpoCzMa, 2, m, &cDelay_kqpoCzMa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ls58UR87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Z9JkdeHy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_MYbxK9SC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yrTI7bzk, 0, m, &cVar_yrTI7bzk_sendMessage);
  cMsg_mwNhCIfn_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_rf4irwnQ, 0, m, &cTabhead_rf4irwnQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EAQa2hyp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_goLmuVA1_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_goLmuVA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_I3foLUpf_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_vDX1Sk5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vDX1Sk5L, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uYY5fZAu, 0, m, &cDelay_uYY5fZAu_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vDX1Sk5L, 0, m, &cDelay_vDX1Sk5L_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_lCD32ksE, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_uYY5fZAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uYY5fZAu, m);
  cMsg_ZpzEsPTV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_MvzWSIAk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_4tvWdzdc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_thN8Jpyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H37aPCtq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_ULissyrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1E5RrY0m_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vDX1Sk5L, 2, m, &cDelay_vDX1Sk5L_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_e24t1MLl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_H37aPCtq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ULissyrp, 0, m, &hTable_ULissyrp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_I3foLUpf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_thN8Jpyd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZpzEsPTV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ULissyrp, 0, m, &hTable_ULissyrp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_e24t1MLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vDX1Sk5L, 0, m, &cDelay_vDX1Sk5L_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1E5RrY0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_uYY5fZAu, 2, m, &cDelay_uYY5fZAu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4tvWdzdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_lCD32ksE, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_lqA7i9xe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C8cbEhKJ, HV_BINOP_SUBTRACT, 0, m, &cBinop_C8cbEhKJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PfrmImY8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QRvZPVSH_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_QRvZPVSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_tGdrXpCS_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_NgDPgs0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G9FLOk66_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_7Vaq8Sgh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7Vaq8Sgh, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rTghhiZu, 0, m, &cDelay_rTghhiZu_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_YgIkX0EZ, 0, m, &sTabread_YgIkX0EZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_rTghhiZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rTghhiZu, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_YgIkX0EZ, 0, m, &sTabread_YgIkX0EZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rTghhiZu, 0, m, &cDelay_rTghhiZu_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_YgIkX0EZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_mNGEltvB, HV_BINOP_SUBTRACT, 0, m, &cBinop_mNGEltvB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_qS8cnV3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_68XSSo9U, HV_BINOP_MAX, 0, m, &cBinop_68XSSo9U_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tGdrXpCS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qS8cnV3X, HV_BINOP_MULTIPLY, 0, m, &cBinop_qS8cnV3X_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_C8cbEhKJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IO31qDG6_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_YgIkX0EZ, 0, m, &sTabread_YgIkX0EZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PkvtIccH_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_NtVfYhx8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mNGEltvB, HV_BINOP_SUBTRACT, 1, m, &cBinop_mNGEltvB_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rTghhiZu, 2, m, &cDelay_rTghhiZu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_G9FLOk66_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NtVfYhx8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IO31qDG6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7Vaq8Sgh, 0, m, &cDelay_7Vaq8Sgh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rTghhiZu, 0, m, &cDelay_rTghhiZu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lWt3VI0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_68XSSo9U, HV_BINOP_MAX, 1, m, &cBinop_68XSSo9U_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_68XSSo9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C8cbEhKJ, HV_BINOP_SUBTRACT, 1, m, &cBinop_C8cbEhKJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PkvtIccH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7Vaq8Sgh, 0, m, &cDelay_7Vaq8Sgh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HsRbqpip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7Vaq8Sgh, 2, m, &cDelay_7Vaq8Sgh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mNGEltvB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_HsRbqpip_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DTnv94Kc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NgDPgs0Q, 0, m, &cVar_NgDPgs0Q_sendMessage);
  cMsg_PfrmImY8_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_lqA7i9xe, 0, m, &cTabhead_lqA7i9xe_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Mg4vfN3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_N65UJtdA, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Fe079nwl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WtpD0Gsk, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_F1h1WDnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MWz2DHHg, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_bGSz3Jac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Z1TpEUHa, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_gnpkZiPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8CLwTcW5, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_KG9dEepr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_c9Vv0yPN, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Jvv7OZP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e16Q2KvC, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_859dlHtd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e3LQBVbL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_jY29YHkJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xvF6Cnou, 0, m, &cSlice_xvF6Cnou_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_xvF6Cnou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_f5Mra0f1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_f5Mra0f1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_lJuSV4wK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_f5Mra0f1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_f5Mra0f1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2tVSyGDU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_WO3ihbAS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7EljwBeR, 0, m, &cSlice_7EljwBeR_sendMessage);
      break;
    }
    default: {
      cSwitchcase_QohfkT7l_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_7EljwBeR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_nBhd7iWj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_nBhd7iWj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_JeyQPUGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nBhd7iWj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_nBhd7iWj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xSLalnLB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_BQnc5oy9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xvQ3vigJ, 0, m, &cSlice_xvQ3vigJ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_jY29YHkJ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_xvQ3vigJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9iI6ulci_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9iI6ulci_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_JfOQgcq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9iI6ulci_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_9iI6ulci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5oB3GbW0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_TclwkDWf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_4KNu9rv6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4KNu9rv6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_fPxK67X9_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_R3yx35MH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xnXWbSxb_sendMessage(_c, 0, m);
  cMsg_R8yYOlGa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_L0QJEW9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vl9F4hMG_sendMessage(_c, 0, m);
  cMsg_SCPCtUhg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_fPxK67X9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_stsyTA16_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_stsyTA16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yBKhTAF9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LJILrfdH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yBKhTAF9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_AbtNk1Xj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LJILrfdH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mgI8DBTR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_AbtNk1Xj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WUMRykhK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mgI8DBTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_QfRnDgtf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QfRnDgtf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_keInf0ve_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WUMRykhK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_R3yx35MH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_keInf0ve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_L0QJEW9X_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8HzZZ6v6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_zKi7yRJa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zKi7yRJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_T3xTK6cu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_T3xTK6cu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_cU9FZNsb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cU9FZNsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KrkQSkiB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_33IHvBOs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KrkQSkiB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_azIUgFsE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_33IHvBOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cpKfLDqU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_azIUgFsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pLpt9DpU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cpKfLDqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_O94UfMOG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_O94UfMOG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WwKW3mIz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WwKW3mIz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1Tj43Czm_sendMessage(_c, 0, m);
  cMsg_2aIiodY0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_pLpt9DpU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jtdRsOsN_sendMessage(_c, 0, m);
  cMsg_Fln0Qyuc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_VmJAyR8h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_0suzCpHs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0suzCpHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gJMVmZk7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_INbm7LWf_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ED8TD539_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_qcr6DruE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OZK42rW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4L7T34R3_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_4L7T34R3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ERjjfsCE, HV_BINOP_DIVIDE, 1, m, &cBinop_ERjjfsCE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gJMVmZk7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0eEH6K7c_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0eEH6K7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_uK6fvLe4, m);
}

void Heavy_WSTD_DL3Y::cMsg_PuaUxyDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_NBFfvkgx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NBFfvkgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_VmJAyR8h_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_INbm7LWf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3wErOXN5, m);
}

void Heavy_WSTD_DL3Y::cBinop_qcr6DruE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_PF44jncR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PF44jncR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ERjjfsCE, HV_BINOP_DIVIDE, 0, m, &cBinop_ERjjfsCE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ERjjfsCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PuaUxyDZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_3rudTNEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_TqFjEhsv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TqFjEhsv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Ui9ouFb9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_YTmAJ1sj_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_eP31zxli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_yQaHj5xq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eDZuXnBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WAaiiFvX_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_WAaiiFvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gRffBZ3n, HV_BINOP_DIVIDE, 1, m, &cBinop_gRffBZ3n_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ui9ouFb9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QgZm9RWL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QgZm9RWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_j6G5hSeR, m);
}

void Heavy_WSTD_DL3Y::cMsg_reVDMGBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5bHrPak6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5bHrPak6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_3rudTNEM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YTmAJ1sj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_76KePY8D, m);
}

void Heavy_WSTD_DL3Y::cBinop_yQaHj5xq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_b1Z9a6BN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_b1Z9a6BN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gRffBZ3n, HV_BINOP_DIVIDE, 0, m, &cBinop_gRffBZ3n_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gRffBZ3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_reVDMGBI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_BLdF1htW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GXv8UDmv, HV_BINOP_MULTIPLY, 0, m, &cBinop_GXv8UDmv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kY0PcWa0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wrhQWg2t_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_wrhQWg2t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yax1CL7k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_GXv8UDmv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_vJ813fyU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nTUnbl0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GXv8UDmv, HV_BINOP_MULTIPLY, 1, m, &cBinop_GXv8UDmv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Yax1CL7k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_nTUnbl0R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vJ813fyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_hVsAfdMC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hVsAfdMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_R8KxgqiX_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_XhCODwB3, m);
}

void Heavy_WSTD_DL3Y::cBinop_R8KxgqiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3Ek4F72y, m);
}

void Heavy_WSTD_DL3Y::cVar_OseGkUYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DfiD2fip, HV_BINOP_MULTIPLY, 0, m, &cBinop_DfiD2fip_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_M9k5UzyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AZXDSpWC_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_AZXDSpWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_98r01Q9M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_DfiD2fip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_UxK4mGZD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UW6A6Wmj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DfiD2fip, HV_BINOP_MULTIPLY, 1, m, &cBinop_DfiD2fip_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_98r01Q9M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_UW6A6Wmj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UxK4mGZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_2UJf2Yvn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2UJf2Yvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_NBDClY9H_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_8ORepZw7, m);
}

void Heavy_WSTD_DL3Y::cBinop_NBDClY9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6ckZ2wdP, m);
}

void Heavy_WSTD_DL3Y::sEnv_krMTioBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wSzQdMMo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QOcxu2YC_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_LeB4ZprE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_smoWJGhH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_8koZxHUy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_N8MF0Rr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3pUkrpk5, HV_BINOP_POW, 0, m, &cBinop_3pUkrpk5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3pUkrpk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2cQ9rSo8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_UcsptEkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_fJccYr8D_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QOcxu2YC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LeB4ZprE, 0, m, &cIf_LeB4ZprE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wSzQdMMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_htQfHhRJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_htQfHhRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LeB4ZprE, 1, m, &cIf_LeB4ZprE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8koZxHUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_UcsptEkP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_smoWJGhH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_2cQ9rSo8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_fJccYr8D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3pUkrpk5, HV_BINOP_POW, 1, m, &cBinop_3pUkrpk5_sendMessage);
  cMsg_N8MF0Rr3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_vTuS20a3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XiwaYKgw, HV_BINOP_MULTIPLY, 0, m, &cBinop_XiwaYKgw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7DMqPo6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9IM6NtTk_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_9IM6NtTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8t4wZvOm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_XiwaYKgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_OPvwOOgv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iFmykSN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XiwaYKgw, HV_BINOP_MULTIPLY, 1, m, &cBinop_XiwaYKgw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8t4wZvOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_iFmykSN8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OPvwOOgv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_YqylXLWv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YqylXLWv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_8h0v7l9I_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_xokkUKU2, m);
}

void Heavy_WSTD_DL3Y::cBinop_8h0v7l9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_IPdAf4ij, m);
}

void Heavy_WSTD_DL3Y::cMsg_2cQ9rSo8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3zdykoXP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3zdykoXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_7VYzuSOu, m);
}

void Heavy_WSTD_DL3Y::sEnv_XeyV0Ym3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ITnhfATs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VYC2OYJC_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_qvv44Wan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_9wJbThp7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_oDJJf4gZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_JnFnFh57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OUkzYUSa, HV_BINOP_POW, 0, m, &cBinop_OUkzYUSa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OUkzYUSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_luVJQ2fj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_iEJDAJhC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Y73KgTBJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VYC2OYJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qvv44Wan, 0, m, &cIf_qvv44Wan_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ITnhfATs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mbMKxDaY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mbMKxDaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qvv44Wan, 1, m, &cIf_qvv44Wan_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oDJJf4gZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_iEJDAJhC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9wJbThp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_luVJQ2fj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Y73KgTBJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OUkzYUSa, HV_BINOP_POW, 1, m, &cBinop_OUkzYUSa_sendMessage);
  cMsg_JnFnFh57_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_QGqNZlnT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XEvRRxEj, HV_BINOP_MULTIPLY, 0, m, &cBinop_XEvRRxEj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ifwtMf0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wIGUAQj4_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_wIGUAQj4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bO0TKcyC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_XEvRRxEj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Prt5FHs1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ti46ooDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XEvRRxEj, HV_BINOP_MULTIPLY, 1, m, &cBinop_XEvRRxEj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bO0TKcyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ti46ooDv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Prt5FHs1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_azg71xLp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_azg71xLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_jH7zjHA8_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ILTDV76F, m);
}

void Heavy_WSTD_DL3Y::cBinop_jH7zjHA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_KMtsKznu, m);
}

void Heavy_WSTD_DL3Y::cMsg_luVJQ2fj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Ijy6v7OJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ijy6v7OJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_mUPS5F7G, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_QohfkT7l_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Eh3e7R1P, 0, m, &cSlice_Eh3e7R1P_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BQnc5oy9_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_Eh3e7R1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rIr2F1lF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rIr2F1lF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_DTFHTi7r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rIr2F1lF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_rIr2F1lF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_swMhpeo3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_upwP4bDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zCc1l6rm_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_zCc1l6rm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9OErGHQD_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_TkijY6Ef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TkijY6Ef, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h5PDnZvd, 0, m, &cDelay_h5PDnZvd_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TkijY6Ef, 0, m, &cDelay_TkijY6Ef_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_GVaI3B51, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_h5PDnZvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_h5PDnZvd, m);
  cMsg_H2jrBXpa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_w3lLi4GV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_2Tzipi0F_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_de4Nix9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E71lToPe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_tIkcpiTQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gbYKx5AP_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TkijY6Ef, 2, m, &cDelay_TkijY6Ef_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cS8xIToc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_E71lToPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_tIkcpiTQ, 0, m, &hTable_tIkcpiTQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9OErGHQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_de4Nix9O_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_H2jrBXpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_tIkcpiTQ, 0, m, &hTable_tIkcpiTQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cS8xIToc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TkijY6Ef, 0, m, &cDelay_TkijY6Ef_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gbYKx5AP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_h5PDnZvd, 2, m, &cDelay_h5PDnZvd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2Tzipi0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_GVaI3B51, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_yjxowaRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NtlLjZFm, HV_BINOP_SUBTRACT, 0, m, &cBinop_NtlLjZFm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QsLk2d8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uO2tiiBQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_uO2tiiBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_4GzMqHBE_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_WN3NeLVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dqy2J9Hh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_ixrkTwNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ixrkTwNC, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ywZrNkZO, 0, m, &cDelay_ywZrNkZO_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_H8j3Mv5R, 0, m, &sTabread_H8j3Mv5R_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_ywZrNkZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ywZrNkZO, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_H8j3Mv5R, 0, m, &sTabread_H8j3Mv5R_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ywZrNkZO, 0, m, &cDelay_ywZrNkZO_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_H8j3Mv5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_2OIpGRX5, HV_BINOP_SUBTRACT, 0, m, &cBinop_2OIpGRX5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_kS6OsUbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9HxIYjlG, HV_BINOP_MAX, 0, m, &cBinop_9HxIYjlG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4GzMqHBE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kS6OsUbT, HV_BINOP_MULTIPLY, 0, m, &cBinop_kS6OsUbT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NtlLjZFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hRRJXtKp_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_H8j3Mv5R, 0, m, &sTabread_H8j3Mv5R_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jgIK2XZP_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_WKA7ZewX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2OIpGRX5, HV_BINOP_SUBTRACT, 1, m, &cBinop_2OIpGRX5_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ywZrNkZO, 2, m, &cDelay_ywZrNkZO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dqy2J9Hh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WKA7ZewX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hRRJXtKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ixrkTwNC, 0, m, &cDelay_ixrkTwNC_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ywZrNkZO, 0, m, &cDelay_ywZrNkZO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5oSDOjwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_9HxIYjlG, HV_BINOP_MAX, 1, m, &cBinop_9HxIYjlG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9HxIYjlG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NtlLjZFm, HV_BINOP_SUBTRACT, 1, m, &cBinop_NtlLjZFm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jgIK2XZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ixrkTwNC, 0, m, &cDelay_ixrkTwNC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hWyfBdKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ixrkTwNC, 2, m, &cDelay_ixrkTwNC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2OIpGRX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_hWyfBdKm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9pvFFjA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WN3NeLVc, 0, m, &cVar_WN3NeLVc_sendMessage);
  cMsg_QsLk2d8K_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_yjxowaRp, 0, m, &cTabhead_yjxowaRp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fsffM8Ti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RfdDIsA7_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_RfdDIsA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Rn6uJJDs_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_1l6rhR8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1l6rhR8U, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kl4xJxie, 0, m, &cDelay_kl4xJxie_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1l6rhR8U, 0, m, &cDelay_1l6rhR8U_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_hxXA0Ub9, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_kl4xJxie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kl4xJxie, m);
  cMsg_TJVGzukp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_c3OQpieL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_G9qY07bh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_GkrHCv52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eiA881kD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_R6QC9LMG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_salKehNw_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1l6rhR8U, 2, m, &cDelay_1l6rhR8U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Bz2rXGGB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eiA881kD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_R6QC9LMG, 0, m, &hTable_R6QC9LMG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Rn6uJJDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_GkrHCv52_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TJVGzukp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_R6QC9LMG, 0, m, &hTable_R6QC9LMG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Bz2rXGGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1l6rhR8U, 0, m, &cDelay_1l6rhR8U_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_salKehNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_kl4xJxie, 2, m, &cDelay_kl4xJxie_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_G9qY07bh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_hxXA0Ub9, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_dp7MHElX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xlgd6JhG, HV_BINOP_SUBTRACT, 0, m, &cBinop_xlgd6JhG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_sCQ85eqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_etB9szBo_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_etB9szBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qVYp7Gt9_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_RGRsFYTT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EeDZt7pF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_tT8vQaUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tT8vQaUI, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tpY7ePd8, 0, m, &cDelay_tpY7ePd8_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_1duYvKVV, 0, m, &sTabread_1duYvKVV_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_tpY7ePd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tpY7ePd8, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_1duYvKVV, 0, m, &sTabread_1duYvKVV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tpY7ePd8, 0, m, &cDelay_tpY7ePd8_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_1duYvKVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_lUkTV9kf, HV_BINOP_SUBTRACT, 0, m, &cBinop_lUkTV9kf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_YzK6Zf00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fq3TwX0l, HV_BINOP_MAX, 0, m, &cBinop_fq3TwX0l_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qVYp7Gt9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YzK6Zf00, HV_BINOP_MULTIPLY, 0, m, &cBinop_YzK6Zf00_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xlgd6JhG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h4NKzaT7_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_1duYvKVV, 0, m, &sTabread_1duYvKVV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WCsKF7Wo_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ifjBF60H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lUkTV9kf, HV_BINOP_SUBTRACT, 1, m, &cBinop_lUkTV9kf_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tpY7ePd8, 2, m, &cDelay_tpY7ePd8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EeDZt7pF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ifjBF60H_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_h4NKzaT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tT8vQaUI, 0, m, &cDelay_tT8vQaUI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tpY7ePd8, 0, m, &cDelay_tpY7ePd8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5xJblPbs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_fq3TwX0l, HV_BINOP_MAX, 1, m, &cBinop_fq3TwX0l_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fq3TwX0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xlgd6JhG, HV_BINOP_SUBTRACT, 1, m, &cBinop_xlgd6JhG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WCsKF7Wo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tT8vQaUI, 0, m, &cDelay_tT8vQaUI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oZL3K2hn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tT8vQaUI, 2, m, &cDelay_tT8vQaUI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lUkTV9kf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_oZL3K2hn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7xVd6spl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RGRsFYTT, 0, m, &cVar_RGRsFYTT_sendMessage);
  cMsg_sCQ85eqi_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_dp7MHElX, 0, m, &cTabhead_dp7MHElX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xnXWbSxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SkqZvgbC, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_vl9F4hMG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kbC7tlW3, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_SCPCtUhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gUYLvKUv, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_R8yYOlGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mZo6grBN, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Fln0Qyuc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZPnTg4Ib, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_1Tj43Czm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0vmAP1Gf, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_jtdRsOsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XBVr5HVD, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_2aIiodY0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uPiQ8yFp, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_WLLlimgi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dJ52ODpa, 0, m, &cSlice_dJ52ODpa_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_dJ52ODpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_w0xuoYer_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_w0xuoYer_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_0cZ72tdI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_w0xuoYer_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_w0xuoYer_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_y0Xt0krk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_u4fWO8Nj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KT7b0ZO7, 0, m, &cSlice_KT7b0ZO7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_eHdkqyA7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_KT7b0ZO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KzUK3Ohk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KzUK3Ohk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_LsHytMnZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KzUK3Ohk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_KzUK3Ohk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bVB9sUC1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_EaDxofG0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Afd38MNH, 0, m, &cSlice_Afd38MNH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_WLLlimgi_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_Afd38MNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8qJjfJf2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8qJjfJf2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_1FdGZiUq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8qJjfJf2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_8qJjfJf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GIfFJYiA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_CqvC0HP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_tDdfYx2L_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tDdfYx2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_3fsHsLJg_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_zdmiaLzu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6l44rsRU_sendMessage(_c, 0, m);
  cMsg_13Oqpmqt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_BJN8yBmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JtLwlyDG_sendMessage(_c, 0, m);
  cMsg_JbiKjf0a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_3fsHsLJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_G5ct8x5Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_G5ct8x5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gyyW978N_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TFYxUnpr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TFYxUnpr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e86kjOCr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_gyyW978N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9JwHzbKR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9JwHzbKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Bq5rCamb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_e86kjOCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_U82G8sRr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_U82G8sRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9meOjRkD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Bq5rCamb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_zdmiaLzu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9meOjRkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_BJN8yBmq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vsaFd46z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_MzemqaDX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MzemqaDX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_BWCLLsGg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BWCLLsGg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Qoobmcik_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Qoobmcik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p7vajDfN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A3YBKaGQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_A3YBKaGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7UauRdZw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_p7vajDfN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_OBW0ZHNg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OBW0ZHNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0pghZGFB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7UauRdZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HbEgwwDH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HbEgwwDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_t28OiThf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t28OiThf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kQSM6bTb_sendMessage(_c, 0, m);
  cMsg_QF1UUVXR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_0pghZGFB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gzzg2kan_sendMessage(_c, 0, m);
  cMsg_rriHqTBl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_YW7mjWGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_mAvTNbCr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mAvTNbCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_s1k5fxJD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ey9WEnFu_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_4fWp4xFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_RfDrHeWB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7GSvKBZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PIo2hAnT_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_PIo2hAnT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZIWVcgm2, HV_BINOP_DIVIDE, 1, m, &cBinop_ZIWVcgm2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_s1k5fxJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Whithfrp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Whithfrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_uOeFCiAM, m);
}

void Heavy_WSTD_DL3Y::cMsg_HNQMVaf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_yyX71mMb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yyX71mMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_YW7mjWGj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ey9WEnFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_mYQGE8nj, m);
}

void Heavy_WSTD_DL3Y::cBinop_RfDrHeWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_AHXaHm9d_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AHXaHm9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZIWVcgm2, HV_BINOP_DIVIDE, 0, m, &cBinop_ZIWVcgm2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZIWVcgm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HNQMVaf7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_f2m7qsQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_zQ3bo3fW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zQ3bo3fW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_zotFp7wb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_SuoSUKo9_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_AnYAvHjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_qkImxYQj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8Ir34Eu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nz5aOH6K_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_nz5aOH6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_piJOCK87, HV_BINOP_DIVIDE, 1, m, &cBinop_piJOCK87_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zotFp7wb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_KEAaVSTB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KEAaVSTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_n65hW3z8, m);
}

void Heavy_WSTD_DL3Y::cMsg_t26i1vI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_afvbufcZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_afvbufcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_f2m7qsQZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SuoSUKo9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_v3qS2Prz, m);
}

void Heavy_WSTD_DL3Y::cBinop_qkImxYQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_th6W9qHZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_th6W9qHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_piJOCK87, HV_BINOP_DIVIDE, 0, m, &cBinop_piJOCK87_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_piJOCK87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t26i1vI9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_3NGJbWen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PHyWgwUu, HV_BINOP_MULTIPLY, 0, m, &cBinop_PHyWgwUu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_u04VToff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5u8MIt7t_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_5u8MIt7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F3u1wwvF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PHyWgwUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_76c4PjJf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5KKVtUBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PHyWgwUu, HV_BINOP_MULTIPLY, 1, m, &cBinop_PHyWgwUu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_F3u1wwvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_5KKVtUBb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_76c4PjJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_8NWaaH6L_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8NWaaH6L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_aKtoMfZA_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_KoTCHrby, m);
}

void Heavy_WSTD_DL3Y::cBinop_aKtoMfZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_dFf4AG4d, m);
}

void Heavy_WSTD_DL3Y::cVar_epOBZTyg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YodZxj7I, HV_BINOP_MULTIPLY, 0, m, &cBinop_YodZxj7I_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_u1i0ckea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NB5sSFTm_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_NB5sSFTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ElZhih96_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_YodZxj7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_e4hXEJdy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hJ1ynxsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YodZxj7I, HV_BINOP_MULTIPLY, 1, m, &cBinop_YodZxj7I_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ElZhih96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_hJ1ynxsa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_e4hXEJdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_zFV5wKrf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zFV5wKrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_aY7ATXOL_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_GoroJi3d, m);
}

void Heavy_WSTD_DL3Y::cBinop_aY7ATXOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_LBtFoJGf, m);
}

void Heavy_WSTD_DL3Y::sEnv_Clk8TEtC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7KE5UJ9L_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e0R6gZcw_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_JKv2xJlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_uJ6gekzW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_i4D7FnYd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_jVEhvP8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jLCFLvbu, HV_BINOP_POW, 0, m, &cBinop_jLCFLvbu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jLCFLvbu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H5B2Dkic_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2gDddAoG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_529LFnfs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_e0R6gZcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JKv2xJlP, 0, m, &cIf_JKv2xJlP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7KE5UJ9L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_JonhoK2U_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JonhoK2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JKv2xJlP, 1, m, &cIf_JKv2xJlP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_i4D7FnYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_2gDddAoG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uJ6gekzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_H5B2Dkic_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_529LFnfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jLCFLvbu, HV_BINOP_POW, 1, m, &cBinop_jLCFLvbu_sendMessage);
  cMsg_jVEhvP8N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_lkntZ5tU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OZ4rJAga, HV_BINOP_MULTIPLY, 0, m, &cBinop_OZ4rJAga_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tbvJS2CS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KAft48dU_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_KAft48dU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T0Zfqu2f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OZ4rJAga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_pskhkeSc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nl5kcGKy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OZ4rJAga, HV_BINOP_MULTIPLY, 1, m, &cBinop_OZ4rJAga_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_T0Zfqu2f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_nl5kcGKy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pskhkeSc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_rpAY1BLy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rpAY1BLy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_6hV261u0_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_1gj8Tchl, m);
}

void Heavy_WSTD_DL3Y::cBinop_6hV261u0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_XVOT2BKK, m);
}

void Heavy_WSTD_DL3Y::cMsg_H5B2Dkic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Jw9uoOWJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Jw9uoOWJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_yDMd3E35, m);
}

void Heavy_WSTD_DL3Y::sEnv_xr4LKy92_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_io6uVRm9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0OOqQXGi_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_IY0XCzTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_UwHF7jdM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_5w601973_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_mJ7nBcT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_R9Mv2V0c, HV_BINOP_POW, 0, m, &cBinop_R9Mv2V0c_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_R9Mv2V0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r10Yltuc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_gf3Mmb2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_hvrC1Ucu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_io6uVRm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_EFg9SpZi_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0OOqQXGi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IY0XCzTL, 0, m, &cIf_IY0XCzTL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EFg9SpZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IY0XCzTL, 1, m, &cIf_IY0XCzTL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5w601973_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_gf3Mmb2J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UwHF7jdM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_r10Yltuc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_hvrC1Ucu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R9Mv2V0c, HV_BINOP_POW, 1, m, &cBinop_R9Mv2V0c_sendMessage);
  cMsg_mJ7nBcT0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_gA8ynNvu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j0kOdvM1, HV_BINOP_MULTIPLY, 0, m, &cBinop_j0kOdvM1_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cTw7IYWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ILExVYsg_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ILExVYsg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wIFw9uKS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_j0kOdvM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_4w8OOmjQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_osQd15YM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j0kOdvM1, HV_BINOP_MULTIPLY, 1, m, &cBinop_j0kOdvM1_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wIFw9uKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_osQd15YM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4w8OOmjQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_VVIVrldV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VVIVrldV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_X9Y2Bmdc_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_4pG47vTr, m);
}

void Heavy_WSTD_DL3Y::cBinop_X9Y2Bmdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_IeU07rch, m);
}

void Heavy_WSTD_DL3Y::cMsg_r10Yltuc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FUG4QoYv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FUG4QoYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_miZDJRwS, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_eHdkqyA7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FyTUX6HZ, 0, m, &cSlice_FyTUX6HZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_EaDxofG0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_FyTUX6HZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LtuWRbXb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LtuWRbXb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_1Zgo1DLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LtuWRbXb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_LtuWRbXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ggeTR9Zt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_bgS4dAYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2nih6Zv4_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_2nih6Zv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_3mjLMi1i_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_465dz1pZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_465dz1pZ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TbByjULY, 0, m, &cDelay_TbByjULY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_465dz1pZ, 0, m, &cDelay_465dz1pZ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9moBFLi6, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_TbByjULY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TbByjULY, m);
  cMsg_ZlNUyb9H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_hIKxNTau_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_L6FbGzTZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_RM1FIG84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dJgsC6rO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_zQosuoI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e5EehnD6_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_465dz1pZ, 2, m, &cDelay_465dz1pZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Fq3s3UNJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dJgsC6rO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_zQosuoI8, 0, m, &hTable_zQosuoI8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3mjLMi1i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_RM1FIG84_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZlNUyb9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_zQosuoI8, 0, m, &hTable_zQosuoI8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Fq3s3UNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_465dz1pZ, 0, m, &cDelay_465dz1pZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_e5EehnD6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_TbByjULY, 2, m, &cDelay_TbByjULY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_L6FbGzTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9moBFLi6, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_XGgUtqGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NiRgAZ7J, HV_BINOP_SUBTRACT, 0, m, &cBinop_NiRgAZ7J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hy13clbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_q3PRy2J6_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_q3PRy2J6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Q9osNELC_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_D4Li5Iy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UWStXozR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_dK81C5DS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dK81C5DS, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Qwc0Ko76, 0, m, &cDelay_Qwc0Ko76_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_TNHnOogk, 0, m, &sTabread_TNHnOogk_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_Qwc0Ko76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Qwc0Ko76, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_TNHnOogk, 0, m, &sTabread_TNHnOogk_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Qwc0Ko76, 0, m, &cDelay_Qwc0Ko76_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_TNHnOogk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_6JHEOy4V, HV_BINOP_SUBTRACT, 0, m, &cBinop_6JHEOy4V_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_FF1KCjVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_428F5rDC, HV_BINOP_MAX, 0, m, &cBinop_428F5rDC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Q9osNELC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FF1KCjVU, HV_BINOP_MULTIPLY, 0, m, &cBinop_FF1KCjVU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NiRgAZ7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LGCWZpzs_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_TNHnOogk, 0, m, &sTabread_TNHnOogk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7XVRFndF_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_WbN42fCx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6JHEOy4V, HV_BINOP_SUBTRACT, 1, m, &cBinop_6JHEOy4V_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Qwc0Ko76, 2, m, &cDelay_Qwc0Ko76_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UWStXozR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WbN42fCx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LGCWZpzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dK81C5DS, 0, m, &cDelay_dK81C5DS_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Qwc0Ko76, 0, m, &cDelay_Qwc0Ko76_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3ozXES5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_428F5rDC, HV_BINOP_MAX, 1, m, &cBinop_428F5rDC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_428F5rDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NiRgAZ7J, HV_BINOP_SUBTRACT, 1, m, &cBinop_NiRgAZ7J_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7XVRFndF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dK81C5DS, 0, m, &cDelay_dK81C5DS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uBoDoJkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dK81C5DS, 2, m, &cDelay_dK81C5DS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6JHEOy4V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_uBoDoJkR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_RRFpntyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_D4Li5Iy1, 0, m, &cVar_D4Li5Iy1_sendMessage);
  cMsg_hy13clbo_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_XGgUtqGl, 0, m, &cTabhead_XGgUtqGl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gr8v4KcK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_G2CKgMNG_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_G2CKgMNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Dd22gwwW_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_YYzsFzKv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YYzsFzKv, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_aSJa9FPk, 0, m, &cDelay_aSJa9FPk_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YYzsFzKv, 0, m, &cDelay_YYzsFzKv_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_qVjxfyn4, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_aSJa9FPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_aSJa9FPk, m);
  cMsg_DVUL87vy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_rGGeV2XV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_UcqmuUOY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_AvXTKWzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m526dG9Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_WdxksEEm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NMTpPVWG_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YYzsFzKv, 2, m, &cDelay_YYzsFzKv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tlJVtoo7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_m526dG9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_WdxksEEm, 0, m, &hTable_WdxksEEm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Dd22gwwW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_AvXTKWzr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DVUL87vy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_WdxksEEm, 0, m, &hTable_WdxksEEm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tlJVtoo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YYzsFzKv, 0, m, &cDelay_YYzsFzKv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NMTpPVWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_aSJa9FPk, 2, m, &cDelay_aSJa9FPk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UcqmuUOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_qVjxfyn4, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_KaSI3bRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SLGTMlgE, HV_BINOP_SUBTRACT, 0, m, &cBinop_SLGTMlgE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ofsPd3y2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BBQHjbGQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_BBQHjbGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_XnO4iqwM_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_xSUIXNAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6wXj6sQF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_P30o4txL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_P30o4txL, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_e5F5PvIP, 0, m, &cDelay_e5F5PvIP_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_lvKnOXvR, 0, m, &sTabread_lvKnOXvR_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_e5F5PvIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_e5F5PvIP, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_lvKnOXvR, 0, m, &sTabread_lvKnOXvR_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_e5F5PvIP, 0, m, &cDelay_e5F5PvIP_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_lvKnOXvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Rna3OhDD, HV_BINOP_SUBTRACT, 0, m, &cBinop_Rna3OhDD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_613FymEU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JAVzRyxf, HV_BINOP_MAX, 0, m, &cBinop_JAVzRyxf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XnO4iqwM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_613FymEU, HV_BINOP_MULTIPLY, 0, m, &cBinop_613FymEU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SLGTMlgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_okoDIjRS_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_lvKnOXvR, 0, m, &sTabread_lvKnOXvR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3lRbgzpQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_uAlvupbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rna3OhDD, HV_BINOP_SUBTRACT, 1, m, &cBinop_Rna3OhDD_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_e5F5PvIP, 2, m, &cDelay_e5F5PvIP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6wXj6sQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uAlvupbM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_okoDIjRS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_P30o4txL, 0, m, &cDelay_P30o4txL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_e5F5PvIP, 0, m, &cDelay_e5F5PvIP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YQxsTB6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_JAVzRyxf, HV_BINOP_MAX, 1, m, &cBinop_JAVzRyxf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JAVzRyxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SLGTMlgE, HV_BINOP_SUBTRACT, 1, m, &cBinop_SLGTMlgE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3lRbgzpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_P30o4txL, 0, m, &cDelay_P30o4txL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZGxr1pqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_P30o4txL, 2, m, &cDelay_P30o4txL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Rna3OhDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ZGxr1pqI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4zZ6txid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xSUIXNAt, 0, m, &cVar_xSUIXNAt_sendMessage);
  cMsg_ofsPd3y2_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_KaSI3bRJ, 0, m, &cTabhead_KaSI3bRJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6l44rsRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qieurbsu, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_JtLwlyDG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oJApnkjr, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_JbiKjf0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Sf2HLxBC, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_13Oqpmqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OZGoxHJP, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_rriHqTBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kf650xJu, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_kQSM6bTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qhEKHd4g, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_gzzg2kan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rnnAS4eN, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_QF1UUVXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NA0Ve62B, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cVar_i2BdllbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5oBPKvdA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_u4IbJrNL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_djd0HAlU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5oBPKvdA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_i2BdllbW, 1, m, &cVar_i2BdllbW_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_NS4oJ32f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_LVL2uYbg, 0, m, &cVar_LVL2uYbg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_HxlCLJr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_LVL2uYbg, 0, m, &cVar_LVL2uYbg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_1NBNOIEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HxlCLJr8, 0, m, &cIf_HxlCLJr8_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_fcrcgDG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NS4oJ32f, 0, m, &cIf_NS4oJ32f_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_xEH12WGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vHlhPmAh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9ufhQ3zM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_jcjBe0NG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vHlhPmAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xEH12WGU, 1, m, &cVar_xEH12WGU_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_JUbX7TjI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_okbRqMm6, 0, m, &cVar_okbRqMm6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_kzFBLqP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_okbRqMm6, 0, m, &cVar_okbRqMm6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_IFOeUItP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kzFBLqP3, 0, m, &cIf_kzFBLqP3_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_FRkQu1KY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JUbX7TjI, 0, m, &cIf_JUbX7TjI_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_e7pywYmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_djl1Aedq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LRK4X2pP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_XUp2kXiK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_djl1Aedq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e7pywYmq, 1, m, &cVar_e7pywYmq_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_EPwqyfxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_C8V0v6Pm, 0, m, &cVar_C8V0v6Pm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_3hOKLDLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_C8V0v6Pm, 0, m, &cVar_C8V0v6Pm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_pGE0PJpt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3hOKLDLe, 0, m, &cIf_3hOKLDLe_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_rJvoVElD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EPwqyfxX, 0, m, &cIf_EPwqyfxX_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_XyJRdx9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KQtRPJbr, HV_BINOP_DIVIDE, 0, m, &cBinop_KQtRPJbr_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_axyATaX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q1tvgkab, HV_BINOP_MULTIPLY, 1, m, &cBinop_q1tvgkab_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_oteCDZPP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GWbLPdgH, 0, m, &cSlice_GWbLPdgH_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_q4JEU4EC, 0, m, &cSlice_q4JEU4EC_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3Etj6s1s_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_712Ea1Kv_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_GWbLPdgH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_BC7fr6ky, 0, m, &cVar_BC7fr6ky_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_BC7fr6ky, 0, m, &cVar_BC7fr6ky_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_q4JEU4EC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_jrdtoZZb, HV_BINOP_NEQ, 1, m, &cBinop_jrdtoZZb_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_BC7fr6ky, 1, m, &cVar_BC7fr6ky_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_jrdtoZZb, HV_BINOP_NEQ, 1, m, &cBinop_jrdtoZZb_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_BC7fr6ky, 1, m, &cVar_BC7fr6ky_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_BC7fr6ky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_lClIHKLO_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_88t8JoBS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qT3d4TBx_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tSZC3esv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_tSZC3esv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BC7fr6ky, 0, m, &cVar_BC7fr6ky_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qT3d4TBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jrdtoZZb, HV_BINOP_NEQ, 1, m, &cBinop_jrdtoZZb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jrdtoZZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_88t8JoBS, 1, m, &cIf_88t8JoBS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_712Ea1Kv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_88t8JoBS, 0, m, &cIf_88t8JoBS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3Etj6s1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jrdtoZZb, HV_BINOP_NEQ, 0, m, &cBinop_jrdtoZZb_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_pbTAsBcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IscyN5KY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AqQ9PcAn_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_JTyYZFOd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zPYzIvjo_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sZ8RkQPF_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Vi53R0Kn_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a9S6Ft7n_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mKS0xwnu_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aHh7zJUP_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yBCDDCzi_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3yISJu6K_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XLFRjQjU_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LoUeH0os_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fH6fOX4e_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CZUgo0VZ_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f2ZUQ64y_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_zPYzIvjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OWgdDHCG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_sZ8RkQPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FfsFq5n1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Vi53R0Kn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IsZ6Ee0v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_a9S6Ft7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kxczGKvM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_mKS0xwnu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CEluW6ln_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_aHh7zJUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mByoenCn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_yBCDDCzi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iMC0eSIW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_3yISJu6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hTGKI39p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_XLFRjQjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YigebZJY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_LoUeH0os_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mAdlrv5s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_fH6fOX4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Od9S22Xg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_CZUgo0VZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AU3tDeR3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_f2ZUQ64y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AMaH7Fkm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_KQtRPJbr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q1tvgkab, HV_BINOP_MULTIPLY, 0, m, &cBinop_q1tvgkab_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_q1tvgkab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oteCDZPP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_AqQ9PcAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XyJRdx9u, 0, m, &cVar_XyJRdx9u_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_axyATaX2, 0, m, &cVar_axyATaX2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_IscyN5KY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KQtRPJbr, HV_BINOP_DIVIDE, 1, m, &cBinop_KQtRPJbr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hipHOP59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XyJRdx9u, 0, m, &cVar_XyJRdx9u_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ckEsxe3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_axyATaX2, 0, m, &cVar_axyATaX2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OWgdDHCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ckEsxe3S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hipHOP59_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FfsFq5n1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ckEsxe3S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hipHOP59_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IsZ6Ee0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ckEsxe3S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hipHOP59_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kxczGKvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ckEsxe3S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hipHOP59_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CEluW6ln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ckEsxe3S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hipHOP59_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mByoenCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ckEsxe3S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hipHOP59_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iMC0eSIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ckEsxe3S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hipHOP59_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hTGKI39p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ckEsxe3S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hipHOP59_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YigebZJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ckEsxe3S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hipHOP59_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mAdlrv5s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ckEsxe3S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hipHOP59_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Od9S22Xg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ckEsxe3S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hipHOP59_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AU3tDeR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ckEsxe3S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hipHOP59_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AMaH7Fkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ckEsxe3S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hipHOP59_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_7Xk1PU3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IUPUS0EF, HV_BINOP_DIVIDE, 0, m, &cBinop_IUPUS0EF_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_JVmJ2scr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_120uPKTm, HV_BINOP_MULTIPLY, 1, m, &cBinop_120uPKTm_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_EMRK6Xd1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ujuuKL39, 0, m, &cSlice_ujuuKL39_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_K1OCLzEO, 0, m, &cSlice_K1OCLzEO_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ffccFqm6_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WcZTHERj_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_ujuuKL39_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_pUZcH9r1, 0, m, &cVar_pUZcH9r1_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_pUZcH9r1, 0, m, &cVar_pUZcH9r1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_K1OCLzEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_dQOPGNKT, HV_BINOP_NEQ, 1, m, &cBinop_dQOPGNKT_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_pUZcH9r1, 1, m, &cVar_pUZcH9r1_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_dQOPGNKT, HV_BINOP_NEQ, 1, m, &cBinop_dQOPGNKT_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_pUZcH9r1, 1, m, &cVar_pUZcH9r1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_pUZcH9r1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_7s7Xs6kj_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_6QO4NtSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ewWrgjs7_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ozZR7L9S_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_ozZR7L9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pUZcH9r1, 0, m, &cVar_pUZcH9r1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ewWrgjs7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dQOPGNKT, HV_BINOP_NEQ, 1, m, &cBinop_dQOPGNKT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dQOPGNKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6QO4NtSj, 1, m, &cIf_6QO4NtSj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WcZTHERj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6QO4NtSj, 0, m, &cIf_6QO4NtSj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ffccFqm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dQOPGNKT, HV_BINOP_NEQ, 0, m, &cBinop_dQOPGNKT_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_TBWcGfxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4JniKweS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4MWZIxvn_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_iXWrumuv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vWg8Rclb_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Yw6rwPaK_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J6A2vVBE_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZNbNr0tR_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9pKU3JQW_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pNVOsU0N_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_igBqMjMR_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S79U0nMX_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mqf8TqB2_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uEogoijG_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W9qttedF_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_whzXu8xG_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SEvCmnhu_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_vWg8Rclb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D1825H13_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Yw6rwPaK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4PsrxbYD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_J6A2vVBE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KCuQu1pE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ZNbNr0tR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AddIFfqL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_9pKU3JQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n91pXsuh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_pNVOsU0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ypQigEy3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_igBqMjMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SGqKggsq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_S79U0nMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0VxoQm3e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_mqf8TqB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sHzWG87A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_uEogoijG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B5eiQULz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_W9qttedF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QIIWqZgc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_whzXu8xG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5BmGAnZg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_SEvCmnhu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ObuPedd5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_IUPUS0EF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_120uPKTm, HV_BINOP_MULTIPLY, 0, m, &cBinop_120uPKTm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_120uPKTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_EMRK6Xd1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_4MWZIxvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7Xk1PU3l, 0, m, &cVar_7Xk1PU3l_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JVmJ2scr, 0, m, &cVar_JVmJ2scr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4JniKweS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IUPUS0EF, HV_BINOP_DIVIDE, 1, m, &cBinop_IUPUS0EF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xHrCeNJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7Xk1PU3l, 0, m, &cVar_7Xk1PU3l_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4KWoIb4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JVmJ2scr, 0, m, &cVar_JVmJ2scr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_D1825H13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4KWoIb4U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xHrCeNJM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4PsrxbYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4KWoIb4U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xHrCeNJM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KCuQu1pE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4KWoIb4U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xHrCeNJM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AddIFfqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4KWoIb4U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xHrCeNJM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_n91pXsuh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4KWoIb4U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xHrCeNJM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ypQigEy3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4KWoIb4U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xHrCeNJM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SGqKggsq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4KWoIb4U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xHrCeNJM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0VxoQm3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4KWoIb4U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xHrCeNJM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_sHzWG87A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4KWoIb4U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xHrCeNJM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_B5eiQULz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4KWoIb4U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xHrCeNJM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QIIWqZgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4KWoIb4U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xHrCeNJM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5BmGAnZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4KWoIb4U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xHrCeNJM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ObuPedd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4KWoIb4U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xHrCeNJM_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_lUkzLh7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ReL3izOe, HV_BINOP_DIVIDE, 0, m, &cBinop_ReL3izOe_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_15PEC01x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rE2NFiA0, HV_BINOP_MULTIPLY, 1, m, &cBinop_rE2NFiA0_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_NXRBtGEK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_lCwm74h2, 0, m, &cSlice_lCwm74h2_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YZi7tRjV, 0, m, &cSlice_YZi7tRjV_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zK0ws2hQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xgexrRkh_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_lCwm74h2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_pLOUl3zX, 0, m, &cVar_pLOUl3zX_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_pLOUl3zX, 0, m, &cVar_pLOUl3zX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_YZi7tRjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_VlxQVwdw, HV_BINOP_NEQ, 1, m, &cBinop_VlxQVwdw_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_pLOUl3zX, 1, m, &cVar_pLOUl3zX_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_VlxQVwdw, HV_BINOP_NEQ, 1, m, &cBinop_VlxQVwdw_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_pLOUl3zX, 1, m, &cVar_pLOUl3zX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_pLOUl3zX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_3x3tJ31e_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_ah454S6O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JdDjIGvp_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_segmhQDr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_segmhQDr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pLOUl3zX, 0, m, &cVar_pLOUl3zX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JdDjIGvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VlxQVwdw, HV_BINOP_NEQ, 1, m, &cBinop_VlxQVwdw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VlxQVwdw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ah454S6O, 1, m, &cIf_ah454S6O_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xgexrRkh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ah454S6O, 0, m, &cIf_ah454S6O_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zK0ws2hQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VlxQVwdw, HV_BINOP_NEQ, 0, m, &cBinop_VlxQVwdw_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_9pjitEH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aSSZGhH4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9XSY2sqL_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_OXP0WG0J_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wnijc9aL_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_McEzx2o9_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BcLuQ6NO_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aGcq4kwy_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0cvALeOC_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xWIWstlF_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_85DDQlK4_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MHGOZztP_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uLShIf5f_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FuzW0HmF_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3wZ0FG5t_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OusitTQa_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DpgHp3Or_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_Wnijc9aL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ygla4NUz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_McEzx2o9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ua4gyf57_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_BcLuQ6NO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uFCx024b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_aGcq4kwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L4rGm0xH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_0cvALeOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w7bluAVp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_xWIWstlF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iRg9FRtl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_85DDQlK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jx64bLVK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_MHGOZztP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Htc9Xr7e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_uLShIf5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JF1Q8Dib_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_FuzW0HmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Dg0Gk9bN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_3wZ0FG5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ifpyibh8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_OusitTQa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eOrMIXfl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_DpgHp3Or_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cDn8qtXG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ReL3izOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rE2NFiA0, HV_BINOP_MULTIPLY, 0, m, &cBinop_rE2NFiA0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rE2NFiA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NXRBtGEK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_aSSZGhH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ReL3izOe, HV_BINOP_DIVIDE, 1, m, &cBinop_ReL3izOe_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9XSY2sqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lUkzLh7N, 0, m, &cVar_lUkzLh7N_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_15PEC01x, 0, m, &cVar_15PEC01x_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jU14HXC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lUkzLh7N, 0, m, &cVar_lUkzLh7N_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SyJZTn77_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_15PEC01x, 0, m, &cVar_15PEC01x_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Ygla4NUz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SyJZTn77_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jU14HXC3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Ua4gyf57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SyJZTn77_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jU14HXC3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uFCx024b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SyJZTn77_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jU14HXC3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_L4rGm0xH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SyJZTn77_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jU14HXC3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_w7bluAVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SyJZTn77_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jU14HXC3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iRg9FRtl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SyJZTn77_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jU14HXC3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Jx64bLVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SyJZTn77_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jU14HXC3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Htc9Xr7e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SyJZTn77_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jU14HXC3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JF1Q8Dib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SyJZTn77_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jU14HXC3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Dg0Gk9bN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SyJZTn77_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jU14HXC3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Ifpyibh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SyJZTn77_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jU14HXC3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eOrMIXfl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SyJZTn77_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jU14HXC3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cDn8qtXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SyJZTn77_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jU14HXC3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_I7sqdTHN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_x006GSyT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SPj4ZmFG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_NuBGf5IU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_x006GSyT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SPj4ZmFG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ENxpPN1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_x006GSyT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SPj4ZmFG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_EM2Sc9DW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_x006GSyT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SPj4ZmFG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_po0Vb0Ry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_x006GSyT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SPj4ZmFG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_0OptP1Ht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_cArpoG2G, 0, m, &cVar_cArpoG2G_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9PbKAeds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_iEYmPGIU, 0, m, &cVar_iEYmPGIU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OPhG1dr6, 0, m, &cVar_OPhG1dr6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yDyiZKqd, 0, m, &cVar_yDyiZKqd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_leBafhu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_eNxKgRoQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_0WDF43JF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_eNxKgRoQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_hHMWKWQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Q0SxFpBF, 0, m, &cVar_Q0SxFpBF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nJKnPyJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FXSOmsEf, 0, m, &cVar_FXSOmsEf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_y3uw9WHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EUnyKhAx, 0, m, &cVar_EUnyKhAx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_m3dYt2Hn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_eNxKgRoQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_4Mi7P3UK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_eNxKgRoQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_5BTq63wC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_WO3ihbAS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_AslT1nNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_WO3ihbAS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_rO6rp4ua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VndE8skE, 0, m, &cVar_VndE8skE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Y97RpgXk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jECbaHV1, 0, m, &cVar_jECbaHV1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FtgZ3obx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nNNVrZty, 0, m, &cVar_nNNVrZty_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZhXjAwqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_WO3ihbAS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_6f6JN8oz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_WO3ihbAS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_rceIHSHr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_u4fWO8Nj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_naokMFGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_u4fWO8Nj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_T7B5Qeih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eCZxXDJF, 0, m, &cVar_eCZxXDJF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_o1P7DrWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oVEoaXRF, 0, m, &cVar_oVEoaXRF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uYQoSgGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DDpKa7gs, 0, m, &cVar_DDpKa7gs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JAOHPJLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_u4fWO8Nj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_hSsvF2gU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_u4fWO8Nj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_lClIHKLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fcrcgDG3, 0, m, &cVar_fcrcgDG3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_djd0HAlU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X6rjy0Zq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZnUQgAar_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_u4IbJrNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JZEz9Ohr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f95KjbTs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JZEz9Ohr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HxlCLJr8, 1, m, &cIf_HxlCLJr8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_f95KjbTs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1NBNOIEN, 0, m, &cVar_1NBNOIEN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZnUQgAar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fcrcgDG3, 0, m, &cVar_fcrcgDG3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_X6rjy0Zq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NS4oJ32f, 1, m, &cIf_NS4oJ32f_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7s7Xs6kj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FRkQu1KY, 0, m, &cVar_FRkQu1KY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jcjBe0NG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3DSYyYOA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_elhpxua9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9ufhQ3zM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4gM2ssAI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_svDlaVGM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_svDlaVGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IFOeUItP, 0, m, &cVar_IFOeUItP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4gM2ssAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kzFBLqP3, 1, m, &cIf_kzFBLqP3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3DSYyYOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JUbX7TjI, 1, m, &cIf_JUbX7TjI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_elhpxua9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FRkQu1KY, 0, m, &cVar_FRkQu1KY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3x3tJ31e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rJvoVElD, 0, m, &cVar_rJvoVElD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XUp2kXiK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9lTq8TDe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KsT4L4iJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LRK4X2pP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Jsp2XiLb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AKvpfyQ4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Jsp2XiLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3hOKLDLe, 1, m, &cIf_3hOKLDLe_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AKvpfyQ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pGE0PJpt, 0, m, &cVar_pGE0PJpt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KsT4L4iJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rJvoVElD, 0, m, &cVar_rJvoVElD_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9lTq8TDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EPwqyfxX, 1, m, &cIf_EPwqyfxX_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_8XnY2iXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iEYmPGIU, 0, m, &cVar_iEYmPGIU_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_e1qvkXlW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OPhG1dr6, 0, m, &cVar_OPhG1dr6_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_aR9ZJvnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yDyiZKqd, 0, m, &cVar_yDyiZKqd_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_nZGIJqNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JyomrtGA, 0, m, &cVar_JyomrtGA_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Af8HtmiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NkG2GKQT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xuAj83FN_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_h2Em4w1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u1HoiWbK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MzEc5FdI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k1PtiV2q_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_kzo7MmnU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h57Al3Q3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cMcRBGNH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ldpr0kks_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ktWlRPnp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fSikGLSB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nDPoAS7e_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7tRsEvBo_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_d9VLBbaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ApdyNQB4_sendMessage(_c, 0, m);
  cMsg_zLnih9ma_sendMessage(_c, 0, m);
  cMsg_eMwVlXgb_sendMessage(_c, 0, m);
  cMsg_YJXVL6d4_sendMessage(_c, 0, m);
  cMsg_abubRSFz_sendMessage(_c, 0, m);
  cMsg_HMTy0m7O_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_fEiru1KC, 0, m, &cVar_fEiru1KC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JyomrtGA, 0, m, &cVar_JyomrtGA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_g3Z234Yo, 0, m, &cVar_g3Z234Yo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7zyL7ajd, 0, m, &cVar_7zyL7ajd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eyQEDmhc, 0, m, &cVar_eyQEDmhc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cpJ0nrvG, 0, m, &cVar_cpJ0nrvG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5m6Gdztd, 0, m, &cVar_5m6Gdztd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yDFg27R4, 0, m, &cVar_yDFg27R4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_auww2T16, 0, m, &cVar_auww2T16_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jirMLA57, 0, m, &cVar_jirMLA57_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pkEFZkkX, 0, m, &cVar_pkEFZkkX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BizChS8l, 0, m, &cVar_BizChS8l_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6QGPj3hb, 0, m, &cVar_6QGPj3hb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jQHhTPcE, 0, m, &cVar_jQHhTPcE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PIw5c6QT, 0, m, &cVar_PIw5c6QT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jTYRqwER, 0, m, &cVar_jTYRqwER_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5b0RviJn, 0, m, &cVar_5b0RviJn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_v9DOjPkW, 0, m, &cVar_v9DOjPkW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_f3nIbJFF, 0, m, &cVar_f3nIbJFF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qWRbiOJY, 0, m, &cVar_qWRbiOJY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PxlzcX9q, 0, m, &cVar_PxlzcX9q_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_H0CEWVNK, 0, m, &cVar_H0CEWVNK_sendMessage);
  cMsg_sE3jsw1P_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_TuGilJ0a, 0, m, &cVar_TuGilJ0a_sendMessage);
  cMsg_NgGqzbmY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_CpRBNaTb, 0, m, &cVar_CpRBNaTb_sendMessage);
  cMsg_7DMqPo6T_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_vTuS20a3, 0, m, &cVar_vTuS20a3_sendMessage);
  cMsg_ifwtMf0F_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_QGqNZlnT, 0, m, &cVar_QGqNZlnT_sendMessage);
  cMsg_tbvJS2CS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lkntZ5tU, 0, m, &cVar_lkntZ5tU_sendMessage);
  cMsg_cTw7IYWB_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_gA8ynNvu, 0, m, &cVar_gA8ynNvu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QL8s1aHe, 0, m, &cVar_QL8s1aHe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uJ9naidV, 0, m, &cVar_uJ9naidV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9AsgeOTx, 0, m, &cVar_9AsgeOTx_sendMessage);
  cMsg_v4IviMyk_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BSUpe4iS, 0, m, &cVar_BSUpe4iS_sendMessage);
  cMsg_edobwPFh_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_frTSLTPQ, 0, m, &cVar_frTSLTPQ_sendMessage);
  cMsg_9WRKfDc5_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BwfW4ZsZ, 0, m, &cVar_BwfW4ZsZ_sendMessage);
  cMsg_CkZtFPex_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NCEeNUML, 0, m, &cVar_NCEeNUML_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_l9w4TKoq, 0, m, &cVar_l9w4TKoq_sendMessage);
  cMsg_Nh7jF84R_sendMessage(_c, 0, m);
  cMsg_EAQa2hyp_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lJuSV4wK, 0, m, &cVar_lJuSV4wK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JeyQPUGb, 0, m, &cVar_JeyQPUGb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JfOQgcq4, 0, m, &cVar_JfOQgcq4_sendMessage);
  cMsg_OZK42rW8_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ED8TD539, 0, m, &cVar_ED8TD539_sendMessage);
  cMsg_eDZuXnBs_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_eP31zxli, 0, m, &cVar_eP31zxli_sendMessage);
  cMsg_kY0PcWa0_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BLdF1htW, 0, m, &cVar_BLdF1htW_sendMessage);
  cMsg_M9k5UzyY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_OseGkUYq, 0, m, &cVar_OseGkUYq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DTFHTi7r, 0, m, &cVar_DTFHTi7r_sendMessage);
  cMsg_upwP4bDH_sendMessage(_c, 0, m);
  cMsg_fsffM8Ti_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_0cZ72tdI, 0, m, &cVar_0cZ72tdI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LsHytMnZ, 0, m, &cVar_LsHytMnZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1FdGZiUq, 0, m, &cVar_1FdGZiUq_sendMessage);
  cMsg_7GSvKBZz_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_4fWp4xFj, 0, m, &cVar_4fWp4xFj_sendMessage);
  cMsg_8Ir34Eu3_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_AnYAvHjT, 0, m, &cVar_AnYAvHjT_sendMessage);
  cMsg_u04VToff_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3NGJbWen, 0, m, &cVar_3NGJbWen_sendMessage);
  cMsg_u1i0ckea_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_epOBZTyg, 0, m, &cVar_epOBZTyg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1Zgo1DLf, 0, m, &cVar_1Zgo1DLf_sendMessage);
  cMsg_bgS4dAYL_sendMessage(_c, 0, m);
  cMsg_gr8v4KcK_sendMessage(_c, 0, m);
  cMsg_9PbKAeds_sendMessage(_c, 0, m);
  cMsg_0OptP1Ht_sendMessage(_c, 0, m);
  cMsg_L19streG_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_yrTI7bzk, 0, m, &cVar_yrTI7bzk_sendMessage);
  cMsg_mwNhCIfn_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_rf4irwnQ, 0, m, &cTabhead_rf4irwnQ_sendMessage);
  cMsg_lWt3VI0a_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NgDPgs0Q, 0, m, &cVar_NgDPgs0Q_sendMessage);
  cMsg_PfrmImY8_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_lqA7i9xe, 0, m, &cTabhead_lqA7i9xe_sendMessage);
  cMsg_5oSDOjwA_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_WN3NeLVc, 0, m, &cVar_WN3NeLVc_sendMessage);
  cMsg_QsLk2d8K_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_yjxowaRp, 0, m, &cTabhead_yjxowaRp_sendMessage);
  cMsg_5xJblPbs_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_RGRsFYTT, 0, m, &cVar_RGRsFYTT_sendMessage);
  cMsg_sCQ85eqi_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_dp7MHElX, 0, m, &cTabhead_dp7MHElX_sendMessage);
  cMsg_3ozXES5b_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_D4Li5Iy1, 0, m, &cVar_D4Li5Iy1_sendMessage);
  cMsg_hy13clbo_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_XGgUtqGl, 0, m, &cTabhead_XGgUtqGl_sendMessage);
  cMsg_YQxsTB6l_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xSUIXNAt, 0, m, &cVar_xSUIXNAt_sendMessage);
  cMsg_ofsPd3y2_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_KaSI3bRJ, 0, m, &cTabhead_KaSI3bRJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_eVVFJLDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5HAg9387, HV_BINOP_MULTIPLY, 0, m, &cBinop_5HAg9387_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_3F9ooVLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_s3c7vwoI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_A7PMMXlc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rsj4Pwyh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_JhT9CRER_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ZYEkmImP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_PfFyAamN_sendMessage);
  cMsg_TPjmMgV1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_QJvfupdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2VqbExI0, HV_BINOP_MULTIPLY, 0, m, &cBinop_2VqbExI0_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_qwrRXovp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_rn1A3Xzo_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_cW44edgK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pgFDMQfY, HV_BINOP_MULTIPLY, 1, m, &cBinop_pgFDMQfY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vbR39qIU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_1QgDYuiU_sendMessage);
  cMsg_BZ4d6vzW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_quAKfBBL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gZset3dE, HV_BINOP_MULTIPLY, 0, m, &cBinop_gZset3dE_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_oiH93lti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R5Jp8Xbd_sendMessage(_c, 0, m);
  cMsg_zKUjE8Kk_sendMessage(_c, 0, m);
  cMsg_0jbsYLn2_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_03Gu1DV1_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_KIjt0MyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_DVoc4jLL_sendMessage);
  cMsg_DPstbrA6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_3qn6oHRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eyQEDmhc, 0, m, &cVar_eyQEDmhc_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_4yZXA2n7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_whhMxUOi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cYO22q0q_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_q8p8jqyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O9KSZ0PN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B7pZIGZY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OS3EHFNw_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_pPiQGzox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6L8VYv5q_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c8AHIEGo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_80q1DJjl_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_hexPoHfL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q2FWroVe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hKVdy9ns_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5KiLt1GQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_VbMm6jGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MEP31SrZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_MEP31SrZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_BotDdeNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_KChntuKT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_VR41Gm6w_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_krlOGGUS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_RqtGF8Gp_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_jZRZbRDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_pvuTkNgc_sendMessage);
  cMsg_ws3puxCT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_AdP0OpFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z95C3egD, HV_BINOP_MULTIPLY, 0, m, &cBinop_Z95C3egD_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_8XKCNsZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_2Pqxnui5_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ewyCV9dM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FiPlHaay, HV_BINOP_MULTIPLY, 1, m, &cBinop_FiPlHaay_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_SQBwvIVA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_su5XuWft_sendMessage);
  cMsg_ZcJ0LNvN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_FOxKVdgZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KPJeRpuF, HV_BINOP_MULTIPLY, 0, m, &cBinop_KPJeRpuF_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_IMKkYORq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5T2wbPPJ_sendMessage(_c, 0, m);
  cMsg_pyFVqKnM_sendMessage(_c, 0, m);
  cMsg_ziFFnr9Y_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_evU2fuSJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_R4SFKb0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_iq1NU4vp_sendMessage);
  cMsg_UMPlh2AO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_w8hGfB25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cArpoG2G, 0, m, &cVar_cArpoG2G_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_xZdyiYPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_hHMWKWQ5_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_FEQ3rbAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_nJKnPyJf_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ZOVfcOdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_y3uw9WHh_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_C7PU5adQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_rO6rp4ua_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_HhlVaHJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Y97RpgXk_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_fowVqtZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_T7B5Qeih_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_TR8B1dqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_o1P7DrWq_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_hdg7Yvca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_uYQoSgGa_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_EOu1cagy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_FtgZ3obx_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_2ss8ImUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sIjZ187J, HV_BINOP_MULTIPLY, 1, m, &cBinop_sIjZ187J_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MYbxK9SC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qS8cnV3X, HV_BINOP_MULTIPLY, 1, m, &cBinop_qS8cnV3X_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DTnv94Kc_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ICcnLC2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Gv8w1eOI, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ryTsxw1M, m);
}

void Heavy_WSTD_DL3Y::cReceive_49jy3Vkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_OgSqSxy3_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_G0df0oxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_TjW78xZ9_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_5oB3GbW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kS6OsUbT, HV_BINOP_MULTIPLY, 1, m, &cBinop_kS6OsUbT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9pvFFjA7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YzK6Zf00, HV_BINOP_MULTIPLY, 1, m, &cBinop_YzK6Zf00_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7xVd6spl_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_swMhpeo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3jGu32vx, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_a0kNWccw, m);
}

void Heavy_WSTD_DL3Y::cReceive_2tVSyGDU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_TclwkDWf_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_xSLalnLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_8HzZZ6v6_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_GIfFJYiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FF1KCjVU, HV_BINOP_MULTIPLY, 1, m, &cBinop_FF1KCjVU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RRFpntyh_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_613FymEU, HV_BINOP_MULTIPLY, 1, m, &cBinop_613FymEU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4zZ6txid_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ggeTR9Zt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_af3JUSCP, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_8Ae3Tq4R, m);
}

void Heavy_WSTD_DL3Y::cReceive_y0Xt0krk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_CqvC0HP6_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_bVB9sUC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_vsaFd46z_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_BMGJpY6E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1NBNOIEN, 0, m, &cVar_1NBNOIEN_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_WuHwjp2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_i2BdllbW, 0, m, &cVar_i2BdllbW_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Jlyrsq9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xEH12WGU, 0, m, &cVar_xEH12WGU_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_vVkarKl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IFOeUItP, 0, m, &cVar_IFOeUItP_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_VAXTZuzA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pGE0PJpt, 0, m, &cVar_pGE0PJpt_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_jDzF8Uhp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e7pywYmq, 0, m, &cVar_e7pywYmq_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_4KHviVyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pbTAsBcY, 0, m, &cVar_pbTAsBcY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TBWcGfxn, 0, m, &cVar_TBWcGfxn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9pjitEH2, 0, m, &cVar_9pjitEH2_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_BWzKE6qK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_iXWrumuv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_hFwbynG1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JTyYZFOd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_qZ0zlwId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_OXP0WG0J_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DL3Y::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_LIDv6rIS, VOf(Bf0));
    __hv_line_f(&sLine_8c5FyQkv, VOf(Bf1));
    __hv_line_f(&sLine_PbvHOSk1, VOf(Bf2));
    __hv_line_f(&sLine_XCUWjx2u, VOf(Bf3));
    __hv_line_f(&sLine_U56XjQpm, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_LPklxT2u, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_S0eUwEr0, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_wDt7bXSi, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_0bWLbtcK, VOf(Bf1));
    __hv_line_f(&sLine_XSNUAFuL, VOf(Bf0));
    __hv_line_f(&sLine_8J6NmQYB, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_UzNXGnQ7, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_uYRUIAgJ, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_bPYfoZpj, VOf(Bf5));
    __hv_line_f(&sLine_qHd4PwFf, VOf(Bf1));
    __hv_line_f(&sLine_40QdUzT9, VOf(Bf2));
    __hv_line_f(&sLine_GJKuPn86, VOf(Bf4));
    __hv_line_f(&sLine_9O6WBTve, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_bX69O7g4, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_VmCXx4sK, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_UeaU7bYE, VOf(Bf6));
    __hv_line_f(&sLine_xbmhxYlF, VOf(Bf2));
    __hv_line_f(&sLine_JZcuUAUV, VOf(Bf1));
    __hv_line_f(&sLine_7bGU525l, VOf(Bf5));
    __hv_line_f(&sLine_M1L1t4eY, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_FiCyN7FB, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_PJYDr6jw, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_T8plHKWI, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_qrKWxgpH, VOf(Bf2));
    __hv_line_f(&sLine_Z5wR9mNX, VOf(Bf6));
    __hv_line_f(&sLine_XbTx5iqZ, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_h3T7jQs6, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_l0HWETlD, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_lZEgVmHV, VOf(Bf8));
    __hv_line_f(&sLine_32Ejqr3u, VOf(Bf2));
    __hv_line_f(&sLine_6RtX3h3U, VOf(Bf1));
    __hv_line_f(&sLine_OxqkCC2F, VOf(Bf7));
    __hv_line_f(&sLine_0Q0OaVzy, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_7nrJB3Rc, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Dr4Eayap, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_WtpD0Gsk, VOf(Bf9));
    __hv_tabread_f(&sTabread_NZ1VWvZz, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_N65UJtdA, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_MWz2DHHg, VOf(Bf9));
    __hv_tabread_f(&sTabread_YgIkX0EZ, VOf(Bf8));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_Z1TpEUHa, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_BJ7GM4pv, VOf(Bf9));
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_s1XQ22LP, VOf(Bf3));
    __hv_rpole_f(&sRPole_t45Kncjf, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_pEozq3vA, VIf(Bf3), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_V0rpZrcw, VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_9Hqwy0um, VIf(Bf3));
    __hv_varread_f(&sVarf_NDlKgxQs, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_AtEVUevM, VOf(Bf5));
    __hv_rpole_f(&sRPole_PCXo1xpf, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_DO9d1nRT, VIf(Bf5), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_GC7HnffY, VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_lCD32ksE, VIf(Bf5));
    __hv_varread_f(&sVarf_Gv8w1eOI, VOf(Bf5));
    __hv_mul_f(VIf(Bf1), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_c9Vv0yPN, VOf(Bf1));
    __hv_varread_f(&sVarf_ryTsxw1M, VOf(Bf3));
    __hv_mul_f(VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_8CLwTcW5, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_AvuWGbS4, VOf(Bf1));
    __hv_varread_f(&sVarf_opEgIqvz, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_GFrx5vap, VOf(Bf1));
    __hv_rpole_f(&sRPole_X2zzRKpq, VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_hKqfr7RZ, VIf(Bf8), &sEnv_hKqfr7RZ_sendMessage);
    __hv_varread_f(&sVarf_EocdERQG, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_hy0hoSSq, VOf(Bf1));
    __hv_rpole_f(&sRPole_yTHfHdkK, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_BJ7GM4pv, VIf(Bf1));
    __hv_line_f(&sLine_e3LQBVbL, VOf(Bf1));
    __hv_line_f(&sLine_e16Q2KvC, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_lKvCRRI2, VOf(Bf1));
    __hv_varread_f(&sVarf_rQ3v3kcI, VOf(Bf3));
    __hv_mul_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_ssK9RI9d, VOf(Bf1));
    __hv_rpole_f(&sRPole_eMPW0vRY, VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_EYHUWXKn, VIf(Bf8), &sEnv_EYHUWXKn_sendMessage);
    __hv_varread_f(&sVarf_h4MYRIoY, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_b4hL9Yaq, VOf(Bf1));
    __hv_rpole_f(&sRPole_VrKyfRHX, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_NDlKgxQs, VIf(Bf1));
    __hv_varwrite_f(&sVarf_QAAKarGp, VIf(Bf2));
    __hv_varread_f(&sVarf_t1vGq2GG, VOf(Bf2));
    __hv_varread_f(&sVarf_93pwV1JT, VOf(Bf1));
    __hv_line_f(&sLine_kbC7tlW3, VOf(Bf8));
    __hv_tabread_f(&sTabread_H8j3Mv5R, VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_SkqZvgbC, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf2), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_gUYLvKUv, VOf(Bf8));
    __hv_tabread_f(&sTabread_1duYvKVV, VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_mZo6grBN, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf1), VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_kFy3pBdp, VOf(Bf8));
    __hv_add_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_3wErOXN5, VOf(Bf2));
    __hv_rpole_f(&sRPole_LayV6bLy, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_TjPzs5KD, VIf(Bf2), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_sub_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_uK6fvLe4, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_tabwrite_f(&sTabwrite_GVaI3B51, VIf(Bf2));
    __hv_varread_f(&sVarf_h15eznd7, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_76KePY8D, VOf(Bf1));
    __hv_rpole_f(&sRPole_6hcL3PV3, VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_nq3WJjlb, VIf(Bf1), VOf(Bf8));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_j6G5hSeR, VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_hxXA0Ub9, VIf(Bf1));
    __hv_varread_f(&sVarf_3jGu32vx, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_0vmAP1Gf, VOf(Bf3));
    __hv_varread_f(&sVarf_a0kNWccw, VOf(Bf2));
    __hv_mul_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_ZPnTg4Ib, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf1), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_7VYzuSOu, VOf(Bf3));
    __hv_varread_f(&sVarf_xokkUKU2, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_IPdAf4ij, VOf(Bf3));
    __hv_rpole_f(&sRPole_cRQbDWKr, VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_krMTioBl, VIf(Bf9), &sEnv_krMTioBl_sendMessage);
    __hv_varread_f(&sVarf_XhCODwB3, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_3Ek4F72y, VOf(Bf3));
    __hv_rpole_f(&sRPole_ULT2nLRf, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_kFy3pBdp, VIf(Bf3));
    __hv_line_f(&sLine_uPiQ8yFp, VOf(Bf3));
    __hv_line_f(&sLine_XBVr5HVD, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_mUPS5F7G, VOf(Bf3));
    __hv_varread_f(&sVarf_ILTDV76F, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_KMtsKznu, VOf(Bf3));
    __hv_rpole_f(&sRPole_nWoAChs7, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_XeyV0Ym3, VIf(Bf9), &sEnv_XeyV0Ym3_sendMessage);
    __hv_varread_f(&sVarf_8ORepZw7, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_6ckZ2wdP, VOf(Bf3));
    __hv_rpole_f(&sRPole_ENaMTTPu, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_h15eznd7, VIf(Bf3));
    __hv_varwrite_f(&sVarf_PtH0yAe8, VIf(Bf5));
    __hv_varread_f(&sVarf_m46LfR0g, VOf(Bf5));
    __hv_varread_f(&sVarf_HH7Fi7Ds, VOf(Bf3));
    __hv_line_f(&sLine_oJApnkjr, VOf(Bf9));
    __hv_tabread_f(&sTabread_TNHnOogk, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_qieurbsu, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_Sf2HLxBC, VOf(Bf9));
    __hv_tabread_f(&sTabread_lvKnOXvR, VOf(Bf8));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_OZGoxHJP, VOf(Bf12));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_de67Gy0Q, VOf(Bf9));
    __hv_add_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_mYQGE8nj, VOf(Bf5));
    __hv_rpole_f(&sRPole_nnAHvv3j, VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_EOMF4avP, VIf(Bf5), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_uOeFCiAM, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_9moBFLi6, VIf(Bf5));
    __hv_varread_f(&sVarf_d37GXx8y, VOf(Bf5));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_v3qS2Prz, VOf(Bf3));
    __hv_rpole_f(&sRPole_6xEzI162, VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_ZYovEKlW, VIf(Bf3), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_n65hW3z8, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_qVjxfyn4, VIf(Bf3));
    __hv_varread_f(&sVarf_af3JUSCP, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_qhEKHd4g, VOf(Bf2));
    __hv_varread_f(&sVarf_8Ae3Tq4R, VOf(Bf5));
    __hv_mul_f(VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_kf650xJu, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_yDMd3E35, VOf(Bf2));
    __hv_varread_f(&sVarf_1gj8Tchl, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_XVOT2BKK, VOf(Bf2));
    __hv_rpole_f(&sRPole_c7mmTfDt, VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_Clk8TEtC, VIf(Bf8), &sEnv_Clk8TEtC_sendMessage);
    __hv_varread_f(&sVarf_KoTCHrby, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_dFf4AG4d, VOf(Bf2));
    __hv_rpole_f(&sRPole_ZoL54tmP, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_de67Gy0Q, VIf(Bf2));
    __hv_line_f(&sLine_NA0Ve62B, VOf(Bf2));
    __hv_line_f(&sLine_rnnAS4eN, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_miZDJRwS, VOf(Bf2));
    __hv_varread_f(&sVarf_4pG47vTr, VOf(Bf5));
    __hv_mul_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_IeU07rch, VOf(Bf2));
    __hv_rpole_f(&sRPole_3wDQZBaT, VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_xr4LKy92, VIf(Bf8), &sEnv_xr4LKy92_sendMessage);
    __hv_varread_f(&sVarf_GoroJi3d, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_LBtFoJGf, VOf(Bf2));
    __hv_rpole_f(&sRPole_upKmZYYz, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_d37GXx8y, VIf(Bf2));
    __hv_varwrite_f(&sVarf_5WBtEl04, VIf(Bf1));
    __hv_varwrite_f(&sVarf_XQHAdqGa, VIf(Bf10));
    __hv_varwrite_f(&sVarf_ZwjB9Smw, VIf(Bf11));
    __hv_varwrite_f(&sVarf_ELbtfhiu, VIf(Bf12));
    __hv_varwrite_f(&sVarf_t1vGq2GG, VIf(Bf0));
    __hv_varwrite_f(&sVarf_93pwV1JT, VIf(Bf6));
    __hv_varwrite_f(&sVarf_m46LfR0g, VIf(Bf4));
    __hv_varwrite_f(&sVarf_HH7Fi7Ds, VIf(Bf7));
    __hv_varread_f(&sVarf_XQHAdqGa, VOf(Bf7));
    __hv_varread_f(&sVarf_ZwjB9Smw, VOf(Bf4));
    __hv_varread_f(&sVarf_ELbtfhiu, VOf(Bf6));
    __hv_add_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_QAAKarGp, VOf(Bf6));
    __hv_varread_f(&sVarf_PtH0yAe8, VOf(Bf7));
    __hv_varread_f(&sVarf_5WBtEl04, VOf(Bf4));
    __hv_add_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf4), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DL3Y::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DL3Y::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
